/* This file was generated by make_unicode_fold_data.py. */
/*-
 * Copyright (c) 2017-2021  K.Kosako
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */


#include "regenc.h"

#define UNICODE_CASEFOLD_VERSION  140000


OnigCodePoint OnigUnicodeFolds1[] = {
 /*   0*/    0x0061,  1,   0x0041, /* LATIN CAPITAL LETTER A */
 /*   3*/    0x0062,  1,   0x0042, /* LATIN CAPITAL LETTER B */
 /*   6*/    0x0063,  1,   0x0043, /* LATIN CAPITAL LETTER C */
 /*   9*/    0x0064,  1,   0x0044, /* LATIN CAPITAL LETTER D */
 /*  12*/    0x0065,  1,   0x0045, /* LATIN CAPITAL LETTER E */
 /*  15*/    0x0066,  1,   0x0046, /* LATIN CAPITAL LETTER F */
 /*  18*/    0x0067,  1,   0x0047, /* LATIN CAPITAL LETTER G */
 /*  21*/    0x0068,  1,   0x0048, /* LATIN CAPITAL LETTER H */
 /*  24*/    0x006a,  1,   0x004a, /* LATIN CAPITAL LETTER J */
 /*  27*/    0x006b,  2,   0x004b,   0x212a, /* LATIN CAPITAL LETTER K */
 /*  31*/    0x006c,  1,   0x004c, /* LATIN CAPITAL LETTER L */
 /*  34*/    0x006d,  1,   0x004d, /* LATIN CAPITAL LETTER M */
 /*  37*/    0x006e,  1,   0x004e, /* LATIN CAPITAL LETTER N */
 /*  40*/    0x006f,  1,   0x004f, /* LATIN CAPITAL LETTER O */
 /*  43*/    0x0070,  1,   0x0050, /* LATIN CAPITAL LETTER P */
 /*  46*/    0x0071,  1,   0x0051, /* LATIN CAPITAL LETTER Q */
 /*  49*/    0x0072,  1,   0x0052, /* LATIN CAPITAL LETTER R */
 /*  52*/    0x0073,  2,   0x0053,   0x017f, /* LATIN CAPITAL LETTER S */
 /*  56*/    0x0074,  1,   0x0054, /* LATIN CAPITAL LETTER T */
 /*  59*/    0x0075,  1,   0x0055, /* LATIN CAPITAL LETTER U */
 /*  62*/    0x0076,  1,   0x0056, /* LATIN CAPITAL LETTER V */
 /*  65*/    0x0077,  1,   0x0057, /* LATIN CAPITAL LETTER W */
 /*  68*/    0x0078,  1,   0x0058, /* LATIN CAPITAL LETTER X */
 /*  71*/    0x0079,  1,   0x0059, /* LATIN CAPITAL LETTER Y */
 /*  74*/    0x007a,  1,   0x005a, /* LATIN CAPITAL LETTER Z */
 /*  77*/    0x00e0,  1,   0x00c0, /* LATIN CAPITAL LETTER A WITH GRAVE */
 /*  80*/    0x00e1,  1,   0x00c1, /* LATIN CAPITAL LETTER A WITH ACUTE */
 /*  83*/    0x00e2,  1,   0x00c2, /* LATIN CAPITAL LETTER A WITH CIRCU.. */
 /*  86*/    0x00e3,  1,   0x00c3, /* LATIN CAPITAL LETTER A WITH TILDE */
 /*  89*/    0x00e4,  1,   0x00c4, /* LATIN CAPITAL LETTER A WITH DIAER.. */
 /*  92*/    0x00e5,  2,   0x00c5,   0x212b, /* LATIN CAPITAL LETTER A WITH RING .. */
 /*  96*/    0x00e6,  1,   0x00c6, /* LATIN CAPITAL LETTER AE */
 /*  99*/    0x00e7,  1,   0x00c7, /* LATIN CAPITAL LETTER C WITH CEDIL.. */
 /* 102*/    0x00e8,  1,   0x00c8, /* LATIN CAPITAL LETTER E WITH GRAVE */
 /* 105*/    0x00e9,  1,   0x00c9, /* LATIN CAPITAL LETTER E WITH ACUTE */
 /* 108*/    0x00ea,  1,   0x00ca, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /* 111*/    0x00eb,  1,   0x00cb, /* LATIN CAPITAL LETTER E WITH DIAER.. */
 /* 114*/    0x00ec,  1,   0x00cc, /* LATIN CAPITAL LETTER I WITH GRAVE */
 /* 117*/    0x00ed,  1,   0x00cd, /* LATIN CAPITAL LETTER I WITH ACUTE */
 /* 120*/    0x00ee,  1,   0x00ce, /* LATIN CAPITAL LETTER I WITH CIRCU.. */
 /* 123*/    0x00ef,  1,   0x00cf, /* LATIN CAPITAL LETTER I WITH DIAER.. */
 /* 126*/    0x00f0,  1,   0x00d0, /* LATIN CAPITAL LETTER ETH */
 /* 129*/    0x00f1,  1,   0x00d1, /* LATIN CAPITAL LETTER N WITH TILDE */
 /* 132*/    0x00f2,  1,   0x00d2, /* LATIN CAPITAL LETTER O WITH GRAVE */
 /* 135*/    0x00f3,  1,   0x00d3, /* LATIN CAPITAL LETTER O WITH ACUTE */
 /* 138*/    0x00f4,  1,   0x00d4, /* LATIN CAPITAL LETTER O WITH CIRCU.. */
 /* 141*/    0x00f5,  1,   0x00d5, /* LATIN CAPITAL LETTER O WITH TILDE */
 /* 144*/    0x00f6,  1,   0x00d6, /* LATIN CAPITAL LETTER O WITH DIAER.. */
 /* 147*/    0x00f8,  1,   0x00d8, /* LATIN CAPITAL LETTER O WITH STROKE */
 /* 150*/    0x00f9,  1,   0x00d9, /* LATIN CAPITAL LETTER U WITH GRAVE */
 /* 153*/    0x00fa,  1,   0x00da, /* LATIN CAPITAL LETTER U WITH ACUTE */
 /* 156*/    0x00fb,  1,   0x00db, /* LATIN CAPITAL LETTER U WITH CIRCU.. */
 /* 159*/    0x00fc,  1,   0x00dc, /* LATIN CAPITAL LETTER U WITH DIAER.. */
 /* 162*/    0x00fd,  1,   0x00dd, /* LATIN CAPITAL LETTER Y WITH ACUTE */
 /* 165*/    0x00fe,  1,   0x00de, /* LATIN CAPITAL LETTER THORN */
 /* 168*/    0x00ff,  1,   0x0178, /* LATIN CAPITAL LETTER Y WITH DIAER.. */
 /* 171*/    0x0101,  1,   0x0100, /* LATIN CAPITAL LETTER A WITH MACRON */
 /* 174*/    0x0103,  1,   0x0102, /* LATIN CAPITAL LETTER A WITH BREVE */
 /* 177*/    0x0105,  1,   0x0104, /* LATIN CAPITAL LETTER A WITH OGONEK */
 /* 180*/    0x0107,  1,   0x0106, /* LATIN CAPITAL LETTER C WITH ACUTE */
 /* 183*/    0x0109,  1,   0x0108, /* LATIN CAPITAL LETTER C WITH CIRCU.. */
 /* 186*/    0x010b,  1,   0x010a, /* LATIN CAPITAL LETTER C WITH DOT A.. */
 /* 189*/    0x010d,  1,   0x010c, /* LATIN CAPITAL LETTER C WITH CARON */
 /* 192*/    0x010f,  1,   0x010e, /* LATIN CAPITAL LETTER D WITH CARON */
 /* 195*/    0x0111,  1,   0x0110, /* LATIN CAPITAL LETTER D WITH STROKE */
 /* 198*/    0x0113,  1,   0x0112, /* LATIN CAPITAL LETTER E WITH MACRON */
 /* 201*/    0x0115,  1,   0x0114, /* LATIN CAPITAL LETTER E WITH BREVE */
 /* 204*/    0x0117,  1,   0x0116, /* LATIN CAPITAL LETTER E WITH DOT A.. */
 /* 207*/    0x0119,  1,   0x0118, /* LATIN CAPITAL LETTER E WITH OGONEK */
 /* 210*/    0x011b,  1,   0x011a, /* LATIN CAPITAL LETTER E WITH CARON */
 /* 213*/    0x011d,  1,   0x011c, /* LATIN CAPITAL LETTER G WITH CIRCU.. */
 /* 216*/    0x011f,  1,   0x011e, /* LATIN CAPITAL LETTER G WITH BREVE */
 /* 219*/    0x0121,  1,   0x0120, /* LATIN CAPITAL LETTER G WITH DOT A.. */
 /* 222*/    0x0123,  1,   0x0122, /* LATIN CAPITAL LETTER G WITH CEDIL.. */
 /* 225*/    0x0125,  1,   0x0124, /* LATIN CAPITAL LETTER H WITH CIRCU.. */
 /* 228*/    0x0127,  1,   0x0126, /* LATIN CAPITAL LETTER H WITH STROKE */
 /* 231*/    0x0129,  1,   0x0128, /* LATIN CAPITAL LETTER I WITH TILDE */
 /* 234*/    0x012b,  1,   0x012a, /* LATIN CAPITAL LETTER I WITH MACRON */
 /* 237*/    0x012d,  1,   0x012c, /* LATIN CAPITAL LETTER I WITH BREVE */
 /* 240*/    0x012f,  1,   0x012e, /* LATIN CAPITAL LETTER I WITH OGONEK */
 /* 243*/    0x0133,  1,   0x0132, /* LATIN CAPITAL LIGATURE IJ */
 /* 246*/    0x0135,  1,   0x0134, /* LATIN CAPITAL LETTER J WITH CIRCU.. */
 /* 249*/    0x0137,  1,   0x0136, /* LATIN CAPITAL LETTER K WITH CEDIL.. */
 /* 252*/    0x013a,  1,   0x0139, /* LATIN CAPITAL LETTER L WITH ACUTE */
 /* 255*/    0x013c,  1,   0x013b, /* LATIN CAPITAL LETTER L WITH CEDIL.. */
 /* 258*/    0x013e,  1,   0x013d, /* LATIN CAPITAL LETTER L WITH CARON */
 /* 261*/    0x0140,  1,   0x013f, /* LATIN CAPITAL LETTER L WITH MIDDL.. */
 /* 264*/    0x0142,  1,   0x0141, /* LATIN CAPITAL LETTER L WITH STROKE */
 /* 267*/    0x0144,  1,   0x0143, /* LATIN CAPITAL LETTER N WITH ACUTE */
 /* 270*/    0x0146,  1,   0x0145, /* LATIN CAPITAL LETTER N WITH CEDIL.. */
 /* 273*/    0x0148,  1,   0x0147, /* LATIN CAPITAL LETTER N WITH CARON */
 /* 276*/    0x014b,  1,   0x014a, /* LATIN CAPITAL LETTER ENG */
 /* 279*/    0x014d,  1,   0x014c, /* LATIN CAPITAL LETTER O WITH MACRON */
 /* 282*/    0x014f,  1,   0x014e, /* LATIN CAPITAL LETTER O WITH BREVE */
 /* 285*/    0x0151,  1,   0x0150, /* LATIN CAPITAL LETTER O WITH DOUBL.. */
 /* 288*/    0x0153,  1,   0x0152, /* LATIN CAPITAL LIGATURE OE */
 /* 291*/    0x0155,  1,   0x0154, /* LATIN CAPITAL LETTER R WITH ACUTE */
 /* 294*/    0x0157,  1,   0x0156, /* LATIN CAPITAL LETTER R WITH CEDIL.. */
 /* 297*/    0x0159,  1,   0x0158, /* LATIN CAPITAL LETTER R WITH CARON */
 /* 300*/    0x015b,  1,   0x015a, /* LATIN CAPITAL LETTER S WITH ACUTE */
 /* 303*/    0x015d,  1,   0x015c, /* LATIN CAPITAL LETTER S WITH CIRCU.. */
 /* 306*/    0x015f,  1,   0x015e, /* LATIN CAPITAL LETTER S WITH CEDIL.. */
 /* 309*/    0x0161,  1,   0x0160, /* LATIN CAPITAL LETTER S WITH CARON */
 /* 312*/    0x0163,  1,   0x0162, /* LATIN CAPITAL LETTER T WITH CEDIL.. */
 /* 315*/    0x0165,  1,   0x0164, /* LATIN CAPITAL LETTER T WITH CARON */
 /* 318*/    0x0167,  1,   0x0166, /* LATIN CAPITAL LETTER T WITH STROKE */
 /* 321*/    0x0169,  1,   0x0168, /* LATIN CAPITAL LETTER U WITH TILDE */
 /* 324*/    0x016b,  1,   0x016a, /* LATIN CAPITAL LETTER U WITH MACRON */
 /* 327*/    0x016d,  1,   0x016c, /* LATIN CAPITAL LETTER U WITH BREVE */
 /* 330*/    0x016f,  1,   0x016e, /* LATIN CAPITAL LETTER U WITH RING .. */
 /* 333*/    0x0171,  1,   0x0170, /* LATIN CAPITAL LETTER U WITH DOUBL.. */
 /* 336*/    0x0173,  1,   0x0172, /* LATIN CAPITAL LETTER U WITH OGONEK */
 /* 339*/    0x0175,  1,   0x0174, /* LATIN CAPITAL LETTER W WITH CIRCU.. */
 /* 342*/    0x0177,  1,   0x0176, /* LATIN CAPITAL LETTER Y WITH CIRCU.. */
 /* 345*/    0x017a,  1,   0x0179, /* LATIN CAPITAL LETTER Z WITH ACUTE */
 /* 348*/    0x017c,  1,   0x017b, /* LATIN CAPITAL LETTER Z WITH DOT A.. */
 /* 351*/    0x017e,  1,   0x017d, /* LATIN CAPITAL LETTER Z WITH CARON */
 /* 354*/    0x0180,  1,   0x0243, /* LATIN CAPITAL LETTER B WITH STROKE */
 /* 357*/    0x0183,  1,   0x0182, /* LATIN CAPITAL LETTER B WITH TOPBAR */
 /* 360*/    0x0185,  1,   0x0184, /* LATIN CAPITAL LETTER TONE SIX */
 /* 363*/    0x0188,  1,   0x0187, /* LATIN CAPITAL LETTER C WITH HOOK */
 /* 366*/    0x018c,  1,   0x018b, /* LATIN CAPITAL LETTER D WITH TOPBAR */
 /* 369*/    0x0192,  1,   0x0191, /* LATIN CAPITAL LETTER F WITH HOOK */
 /* 372*/    0x0195,  1,   0x01f6, /* LATIN CAPITAL LETTER HWAIR */
 /* 375*/    0x0199,  1,   0x0198, /* LATIN CAPITAL LETTER K WITH HOOK */
 /* 378*/    0x019a,  1,   0x023d, /* LATIN CAPITAL LETTER L WITH BAR */
 /* 381*/    0x019e,  1,   0x0220, /* LATIN CAPITAL LETTER N WITH LONG .. */
 /* 384*/    0x01a1,  1,   0x01a0, /* LATIN CAPITAL LETTER O WITH HORN */
 /* 387*/    0x01a3,  1,   0x01a2, /* LATIN CAPITAL LETTER OI */
 /* 390*/    0x01a5,  1,   0x01a4, /* LATIN CAPITAL LETTER P WITH HOOK */
 /* 393*/    0x01a8,  1,   0x01a7, /* LATIN CAPITAL LETTER TONE TWO */
 /* 396*/    0x01ad,  1,   0x01ac, /* LATIN CAPITAL LETTER T WITH HOOK */
 /* 399*/    0x01b0,  1,   0x01af, /* LATIN CAPITAL LETTER U WITH HORN */
 /* 402*/    0x01b4,  1,   0x01b3, /* LATIN CAPITAL LETTER Y WITH HOOK */
 /* 405*/    0x01b6,  1,   0x01b5, /* LATIN CAPITAL LETTER Z WITH STROKE */
 /* 408*/    0x01b9,  1,   0x01b8, /* LATIN CAPITAL LETTER EZH REVERSED */
 /* 411*/    0x01bd,  1,   0x01bc, /* LATIN CAPITAL LETTER TONE FIVE */
 /* 414*/    0x01bf,  1,   0x01f7, /* LATIN CAPITAL LETTER WYNN */
 /* 417*/    0x01c6,  2,   0x01c4,   0x01c5, /* LATIN CAPITAL LETTER DZ WITH CARON */
 /* 421*/    0x01c9,  2,   0x01c7,   0x01c8, /* LATIN CAPITAL LETTER LJ */
 /* 425*/    0x01cc,  2,   0x01ca,   0x01cb, /* LATIN CAPITAL LETTER NJ */
 /* 429*/    0x01ce,  1,   0x01cd, /* LATIN CAPITAL LETTER A WITH CARON */
 /* 432*/    0x01d0,  1,   0x01cf, /* LATIN CAPITAL LETTER I WITH CARON */
 /* 435*/    0x01d2,  1,   0x01d1, /* LATIN CAPITAL LETTER O WITH CARON */
 /* 438*/    0x01d4,  1,   0x01d3, /* LATIN CAPITAL LETTER U WITH CARON */
 /* 441*/    0x01d6,  1,   0x01d5, /* LATIN CAPITAL LETTER U WITH DIAER.. */
 /* 444*/    0x01d8,  1,   0x01d7, /* LATIN CAPITAL LETTER U WITH DIAER.. */
 /* 447*/    0x01da,  1,   0x01d9, /* LATIN CAPITAL LETTER U WITH DIAER.. */
 /* 450*/    0x01dc,  1,   0x01db, /* LATIN CAPITAL LETTER U WITH DIAER.. */
 /* 453*/    0x01dd,  1,   0x018e, /* LATIN CAPITAL LETTER REVERSED E */
 /* 456*/    0x01df,  1,   0x01de, /* LATIN CAPITAL LETTER A WITH DIAER.. */
 /* 459*/    0x01e1,  1,   0x01e0, /* LATIN CAPITAL LETTER A WITH DOT A.. */
 /* 462*/    0x01e3,  1,   0x01e2, /* LATIN CAPITAL LETTER AE WITH MACR.. */
 /* 465*/    0x01e5,  1,   0x01e4, /* LATIN CAPITAL LETTER G WITH STROKE */
 /* 468*/    0x01e7,  1,   0x01e6, /* LATIN CAPITAL LETTER G WITH CARON */
 /* 471*/    0x01e9,  1,   0x01e8, /* LATIN CAPITAL LETTER K WITH CARON */
 /* 474*/    0x01eb,  1,   0x01ea, /* LATIN CAPITAL LETTER O WITH OGONEK */
 /* 477*/    0x01ed,  1,   0x01ec, /* LATIN CAPITAL LETTER O WITH OGONE.. */
 /* 480*/    0x01ef,  1,   0x01ee, /* LATIN CAPITAL LETTER EZH WITH CAR.. */
 /* 483*/    0x01f3,  2,   0x01f1,   0x01f2, /* LATIN CAPITAL LETTER DZ */
 /* 487*/    0x01f5,  1,   0x01f4, /* LATIN CAPITAL LETTER G WITH ACUTE */
 /* 490*/    0x01f9,  1,   0x01f8, /* LATIN CAPITAL LETTER N WITH GRAVE */
 /* 493*/    0x01fb,  1,   0x01fa, /* LATIN CAPITAL LETTER A WITH RING .. */
 /* 496*/    0x01fd,  1,   0x01fc, /* LATIN CAPITAL LETTER AE WITH ACUTE */
 /* 499*/    0x01ff,  1,   0x01fe, /* LATIN CAPITAL LETTER O WITH STROK.. */
 /* 502*/    0x0201,  1,   0x0200, /* LATIN CAPITAL LETTER A WITH DOUBL.. */
 /* 505*/    0x0203,  1,   0x0202, /* LATIN CAPITAL LETTER A WITH INVER.. */
 /* 508*/    0x0205,  1,   0x0204, /* LATIN CAPITAL LETTER E WITH DOUBL.. */
 /* 511*/    0x0207,  1,   0x0206, /* LATIN CAPITAL LETTER E WITH INVER.. */
 /* 514*/    0x0209,  1,   0x0208, /* LATIN CAPITAL LETTER I WITH DOUBL.. */
 /* 517*/    0x020b,  1,   0x020a, /* LATIN CAPITAL LETTER I WITH INVER.. */
 /* 520*/    0x020d,  1,   0x020c, /* LATIN CAPITAL LETTER O WITH DOUBL.. */
 /* 523*/    0x020f,  1,   0x020e, /* LATIN CAPITAL LETTER O WITH INVER.. */
 /* 526*/    0x0211,  1,   0x0210, /* LATIN CAPITAL LETTER R WITH DOUBL.. */
 /* 529*/    0x0213,  1,   0x0212, /* LATIN CAPITAL LETTER R WITH INVER.. */
 /* 532*/    0x0215,  1,   0x0214, /* LATIN CAPITAL LETTER U WITH DOUBL.. */
 /* 535*/    0x0217,  1,   0x0216, /* LATIN CAPITAL LETTER U WITH INVER.. */
 /* 538*/    0x0219,  1,   0x0218, /* LATIN CAPITAL LETTER S WITH COMMA.. */
 /* 541*/    0x021b,  1,   0x021a, /* LATIN CAPITAL LETTER T WITH COMMA.. */
 /* 544*/    0x021d,  1,   0x021c, /* LATIN CAPITAL LETTER YOGH */
 /* 547*/    0x021f,  1,   0x021e, /* LATIN CAPITAL LETTER H WITH CARON */
 /* 550*/    0x0223,  1,   0x0222, /* LATIN CAPITAL LETTER OU */
 /* 553*/    0x0225,  1,   0x0224, /* LATIN CAPITAL LETTER Z WITH HOOK */
 /* 556*/    0x0227,  1,   0x0226, /* LATIN CAPITAL LETTER A WITH DOT A.. */
 /* 559*/    0x0229,  1,   0x0228, /* LATIN CAPITAL LETTER E WITH CEDIL.. */
 /* 562*/    0x022b,  1,   0x022a, /* LATIN CAPITAL LETTER O WITH DIAER.. */
 /* 565*/    0x022d,  1,   0x022c, /* LATIN CAPITAL LETTER O WITH TILDE.. */
 /* 568*/    0x022f,  1,   0x022e, /* LATIN CAPITAL LETTER O WITH DOT A.. */
 /* 571*/    0x0231,  1,   0x0230, /* LATIN CAPITAL LETTER O WITH DOT A.. */
 /* 574*/    0x0233,  1,   0x0232, /* LATIN CAPITAL LETTER Y WITH MACRON */
 /* 577*/    0x023c,  1,   0x023b, /* LATIN CAPITAL LETTER C WITH STROKE */
 /* 580*/    0x023f,  1,   0x2c7e, /* LATIN CAPITAL LETTER S WITH SWASH.. */
 /* 583*/    0x0240,  1,   0x2c7f, /* LATIN CAPITAL LETTER Z WITH SWASH.. */
 /* 586*/    0x0242,  1,   0x0241, /* LATIN CAPITAL LETTER GLOTTAL STOP */
 /* 589*/    0x0247,  1,   0x0246, /* LATIN CAPITAL LETTER E WITH STROKE */
 /* 592*/    0x0249,  1,   0x0248, /* LATIN CAPITAL LETTER J WITH STROKE */
 /* 595*/    0x024b,  1,   0x024a, /* LATIN CAPITAL LETTER SMALL Q WITH.. */
 /* 598*/    0x024d,  1,   0x024c, /* LATIN CAPITAL LETTER R WITH STROKE */
 /* 601*/    0x024f,  1,   0x024e, /* LATIN CAPITAL LETTER Y WITH STROKE */
 /* 604*/    0x0250,  1,   0x2c6f, /* LATIN CAPITAL LETTER TURNED A */
 /* 607*/    0x0251,  1,   0x2c6d, /* LATIN CAPITAL LETTER ALPHA */
 /* 610*/    0x0252,  1,   0x2c70, /* LATIN CAPITAL LETTER TURNED ALPHA */
 /* 613*/    0x0253,  1,   0x0181, /* LATIN CAPITAL LETTER B WITH HOOK */
 /* 616*/    0x0254,  1,   0x0186, /* LATIN CAPITAL LETTER OPEN O */
 /* 619*/    0x0256,  1,   0x0189, /* LATIN CAPITAL LETTER AFRICAN D */
 /* 622*/    0x0257,  1,   0x018a, /* LATIN CAPITAL LETTER D WITH HOOK */
 /* 625*/    0x0259,  1,   0x018f, /* LATIN CAPITAL LETTER SCHWA */
 /* 628*/    0x025b,  1,   0x0190, /* LATIN CAPITAL LETTER OPEN E */
 /* 631*/    0x025c,  1,   0xa7ab, /* LATIN CAPITAL LETTER REVERSED OPE.. */
 /* 634*/    0x0260,  1,   0x0193, /* LATIN CAPITAL LETTER G WITH HOOK */
 /* 637*/    0x0261,  1,   0xa7ac, /* LATIN CAPITAL LETTER SCRIPT G */
 /* 640*/    0x0263,  1,   0x0194, /* LATIN CAPITAL LETTER GAMMA */
 /* 643*/    0x0265,  1,   0xa78d, /* LATIN CAPITAL LETTER TURNED H */
 /* 646*/    0x0266,  1,   0xa7aa, /* LATIN CAPITAL LETTER H WITH HOOK */
 /* 649*/    0x0268,  1,   0x0197, /* LATIN CAPITAL LETTER I WITH STROKE */
 /* 652*/    0x0269,  1,   0x0196, /* LATIN CAPITAL LETTER IOTA */
 /* 655*/    0x026a,  1,   0xa7ae, /* LATIN CAPITAL LETTER SMALL CAPITA.. */
 /* 658*/    0x026b,  1,   0x2c62, /* LATIN CAPITAL LETTER L WITH MIDDL.. */
 /* 661*/    0x026c,  1,   0xa7ad, /* LATIN CAPITAL LETTER L WITH BELT */
 /* 664*/    0x026f,  1,   0x019c, /* LATIN CAPITAL LETTER TURNED M */
 /* 667*/    0x0271,  1,   0x2c6e, /* LATIN CAPITAL LETTER M WITH HOOK */
 /* 670*/    0x0272,  1,   0x019d, /* LATIN CAPITAL LETTER N WITH LEFT .. */
 /* 673*/    0x0275,  1,   0x019f, /* LATIN CAPITAL LETTER O WITH MIDDL.. */
 /* 676*/    0x027d,  1,   0x2c64, /* LATIN CAPITAL LETTER R WITH TAIL */
 /* 679*/    0x0280,  1,   0x01a6, /* LATIN LETTER YR */
 /* 682*/    0x0282,  1,   0xa7c5, /* LATIN CAPITAL LETTER S WITH HOOK */
 /* 685*/    0x0283,  1,   0x01a9, /* LATIN CAPITAL LETTER ESH */
 /* 688*/    0x0287,  1,   0xa7b1, /* LATIN CAPITAL LETTER TURNED T */
 /* 691*/    0x0288,  1,   0x01ae, /* LATIN CAPITAL LETTER T WITH RETRO.. */
 /* 694*/    0x0289,  1,   0x0244, /* LATIN CAPITAL LETTER U BAR */
 /* 697*/    0x028a,  1,   0x01b1, /* LATIN CAPITAL LETTER UPSILON */
 /* 700*/    0x028b,  1,   0x01b2, /* LATIN CAPITAL LETTER V WITH HOOK */
 /* 703*/    0x028c,  1,   0x0245, /* LATIN CAPITAL LETTER TURNED V */
 /* 706*/    0x0292,  1,   0x01b7, /* LATIN CAPITAL LETTER EZH */
 /* 709*/    0x029d,  1,   0xa7b2, /* LATIN CAPITAL LETTER J WITH CROSS.. */
 /* 712*/    0x029e,  1,   0xa7b0, /* LATIN CAPITAL LETTER TURNED K */
 /* 715*/    0x0371,  1,   0x0370, /* GREEK CAPITAL LETTER HETA */
 /* 718*/    0x0373,  1,   0x0372, /* GREEK CAPITAL LETTER ARCHAIC SAMPI */
 /* 721*/    0x0377,  1,   0x0376, /* GREEK CAPITAL LETTER PAMPHYLIAN D.. */
 /* 724*/    0x037b,  1,   0x03fd, /* GREEK CAPITAL REVERSED LUNATE SIG.. */
 /* 727*/    0x037c,  1,   0x03fe, /* GREEK CAPITAL DOTTED LUNATE SIGMA.. */
 /* 730*/    0x037d,  1,   0x03ff, /* GREEK CAPITAL REVERSED DOTTED LUN.. */
 /* 733*/    0x03ac,  1,   0x0386, /* GREEK CAPITAL LETTER ALPHA WITH T.. */
 /* 736*/    0x03ad,  1,   0x0388, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /* 739*/    0x03ae,  1,   0x0389, /* GREEK CAPITAL LETTER ETA WITH TON.. */
 /* 742*/    0x03af,  1,   0x038a, /* GREEK CAPITAL LETTER IOTA WITH TO.. */
 /* 745*/    0x03b1,  1,   0x0391, /* GREEK CAPITAL LETTER ALPHA */
 /* 748*/    0x03b2,  2,   0x0392,   0x03d0, /* GREEK CAPITAL LETTER BETA */
 /* 752*/    0x03b3,  1,   0x0393, /* GREEK CAPITAL LETTER GAMMA */
 /* 755*/    0x03b4,  1,   0x0394, /* GREEK CAPITAL LETTER DELTA */
 /* 758*/    0x03b5,  2,   0x0395,   0x03f5, /* GREEK CAPITAL LETTER EPSILON */
 /* 762*/    0x03b6,  1,   0x0396, /* GREEK CAPITAL LETTER ZETA */
 /* 765*/    0x03b7,  1,   0x0397, /* GREEK CAPITAL LETTER ETA */
 /* 768*/    0x03b8,  3,   0x0398,   0x03d1,   0x03f4, /* GREEK CAPITAL LETTER THETA */
 /* 773*/    0x03b9,  3,   0x0345,   0x0399,   0x1fbe, /* COMBINING GREEK YPOGEGRAMMENI */
 /* 778*/    0x03ba,  2,   0x039a,   0x03f0, /* GREEK CAPITAL LETTER KAPPA */
 /* 782*/    0x03bb,  1,   0x039b, /* GREEK CAPITAL LETTER LAMDA */
 /* 785*/    0x03bc,  2,   0x00b5,   0x039c, /* MICRO SIGN */
 /* 789*/    0x03bd,  1,   0x039d, /* GREEK CAPITAL LETTER NU */
 /* 792*/    0x03be,  1,   0x039e, /* GREEK CAPITAL LETTER XI */
 /* 795*/    0x03bf,  1,   0x039f, /* GREEK CAPITAL LETTER OMICRON */
 /* 798*/    0x03c0,  2,   0x03a0,   0x03d6, /* GREEK CAPITAL LETTER PI */
 /* 802*/    0x03c1,  2,   0x03a1,   0x03f1, /* GREEK CAPITAL LETTER RHO */
 /* 806*/    0x03c3,  2,   0x03a3,   0x03c2, /* GREEK CAPITAL LETTER SIGMA */
 /* 810*/    0x03c4,  1,   0x03a4, /* GREEK CAPITAL LETTER TAU */
 /* 813*/    0x03c5,  1,   0x03a5, /* GREEK CAPITAL LETTER UPSILON */
 /* 816*/    0x03c6,  2,   0x03a6,   0x03d5, /* GREEK CAPITAL LETTER PHI */
 /* 820*/    0x03c7,  1,   0x03a7, /* GREEK CAPITAL LETTER CHI */
 /* 823*/    0x03c8,  1,   0x03a8, /* GREEK CAPITAL LETTER PSI */
 /* 826*/    0x03c9,  2,   0x03a9,   0x2126, /* GREEK CAPITAL LETTER OMEGA */
 /* 830*/    0x03ca,  1,   0x03aa, /* GREEK CAPITAL LETTER IOTA WITH DI.. */
 /* 833*/    0x03cb,  1,   0x03ab, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /* 836*/    0x03cc,  1,   0x038c, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /* 839*/    0x03cd,  1,   0x038e, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /* 842*/    0x03ce,  1,   0x038f, /* GREEK CAPITAL LETTER OMEGA WITH T.. */
 /* 845*/    0x03d7,  1,   0x03cf, /* GREEK CAPITAL KAI SYMBOL */
 /* 848*/    0x03d9,  1,   0x03d8, /* GREEK LETTER ARCHAIC KOPPA */
 /* 851*/    0x03db,  1,   0x03da, /* GREEK LETTER STIGMA */
 /* 854*/    0x03dd,  1,   0x03dc, /* GREEK LETTER DIGAMMA */
 /* 857*/    0x03df,  1,   0x03de, /* GREEK LETTER KOPPA */
 /* 860*/    0x03e1,  1,   0x03e0, /* GREEK LETTER SAMPI */
 /* 863*/    0x03e3,  1,   0x03e2, /* COPTIC CAPITAL LETTER SHEI */
 /* 866*/    0x03e5,  1,   0x03e4, /* COPTIC CAPITAL LETTER FEI */
 /* 869*/    0x03e7,  1,   0x03e6, /* COPTIC CAPITAL LETTER KHEI */
 /* 872*/    0x03e9,  1,   0x03e8, /* COPTIC CAPITAL LETTER HORI */
 /* 875*/    0x03eb,  1,   0x03ea, /* COPTIC CAPITAL LETTER GANGIA */
 /* 878*/    0x03ed,  1,   0x03ec, /* COPTIC CAPITAL LETTER SHIMA */
 /* 881*/    0x03ef,  1,   0x03ee, /* COPTIC CAPITAL LETTER DEI */
 /* 884*/    0x03f2,  1,   0x03f9, /* GREEK CAPITAL LUNATE SIGMA SYMBOL */
 /* 887*/    0x03f3,  1,   0x037f, /* GREEK CAPITAL LETTER YOT */
 /* 890*/    0x03f8,  1,   0x03f7, /* GREEK CAPITAL LETTER SHO */
 /* 893*/    0x03fb,  1,   0x03fa, /* GREEK CAPITAL LETTER SAN */
 /* 896*/    0x0430,  1,   0x0410, /* CYRILLIC CAPITAL LETTER A */
 /* 899*/    0x0431,  1,   0x0411, /* CYRILLIC CAPITAL LETTER BE */
 /* 902*/    0x0432,  2,   0x0412,   0x1c80, /* CYRILLIC CAPITAL LETTER VE */
 /* 906*/    0x0433,  1,   0x0413, /* CYRILLIC CAPITAL LETTER GHE */
 /* 909*/    0x0434,  2,   0x0414,   0x1c81, /* CYRILLIC CAPITAL LETTER DE */
 /* 913*/    0x0435,  1,   0x0415, /* CYRILLIC CAPITAL LETTER IE */
 /* 916*/    0x0436,  1,   0x0416, /* CYRILLIC CAPITAL LETTER ZHE */
 /* 919*/    0x0437,  1,   0x0417, /* CYRILLIC CAPITAL LETTER ZE */
 /* 922*/    0x0438,  1,   0x0418, /* CYRILLIC CAPITAL LETTER I */
 /* 925*/    0x0439,  1,   0x0419, /* CYRILLIC CAPITAL LETTER SHORT I */
 /* 928*/    0x043a,  1,   0x041a, /* CYRILLIC CAPITAL LETTER KA */
 /* 931*/    0x043b,  1,   0x041b, /* CYRILLIC CAPITAL LETTER EL */
 /* 934*/    0x043c,  1,   0x041c, /* CYRILLIC CAPITAL LETTER EM */
 /* 937*/    0x043d,  1,   0x041d, /* CYRILLIC CAPITAL LETTER EN */
 /* 940*/    0x043e,  2,   0x041e,   0x1c82, /* CYRILLIC CAPITAL LETTER O */
 /* 944*/    0x043f,  1,   0x041f, /* CYRILLIC CAPITAL LETTER PE */
 /* 947*/    0x0440,  1,   0x0420, /* CYRILLIC CAPITAL LETTER ER */
 /* 950*/    0x0441,  2,   0x0421,   0x1c83, /* CYRILLIC CAPITAL LETTER ES */
 /* 954*/    0x0442,  3,   0x0422,   0x1c84,   0x1c85, /* CYRILLIC CAPITAL LETTER TE */
 /* 959*/    0x0443,  1,   0x0423, /* CYRILLIC CAPITAL LETTER U */
 /* 962*/    0x0444,  1,   0x0424, /* CYRILLIC CAPITAL LETTER EF */
 /* 965*/    0x0445,  1,   0x0425, /* CYRILLIC CAPITAL LETTER HA */
 /* 968*/    0x0446,  1,   0x0426, /* CYRILLIC CAPITAL LETTER TSE */
 /* 971*/    0x0447,  1,   0x0427, /* CYRILLIC CAPITAL LETTER CHE */
 /* 974*/    0x0448,  1,   0x0428, /* CYRILLIC CAPITAL LETTER SHA */
 /* 977*/    0x0449,  1,   0x0429, /* CYRILLIC CAPITAL LETTER SHCHA */
 /* 980*/    0x044a,  2,   0x042a,   0x1c86, /* CYRILLIC CAPITAL LETTER HARD SIGN */
 /* 984*/    0x044b,  1,   0x042b, /* CYRILLIC CAPITAL LETTER YERU */
 /* 987*/    0x044c,  1,   0x042c, /* CYRILLIC CAPITAL LETTER SOFT SIGN */
 /* 990*/    0x044d,  1,   0x042d, /* CYRILLIC CAPITAL LETTER E */
 /* 993*/    0x044e,  1,   0x042e, /* CYRILLIC CAPITAL LETTER YU */
 /* 996*/    0x044f,  1,   0x042f, /* CYRILLIC CAPITAL LETTER YA */
 /* 999*/    0x0450,  1,   0x0400, /* CYRILLIC CAPITAL LETTER IE WITH G.. */
 /*1002*/    0x0451,  1,   0x0401, /* CYRILLIC CAPITAL LETTER IO */
 /*1005*/    0x0452,  1,   0x0402, /* CYRILLIC CAPITAL LETTER DJE */
 /*1008*/    0x0453,  1,   0x0403, /* CYRILLIC CAPITAL LETTER GJE */
 /*1011*/    0x0454,  1,   0x0404, /* CYRILLIC CAPITAL LETTER UKRAINIAN.. */
 /*1014*/    0x0455,  1,   0x0405, /* CYRILLIC CAPITAL LETTER DZE */
 /*1017*/    0x0456,  1,   0x0406, /* CYRILLIC CAPITAL LETTER BYELORUSS.. */
 /*1020*/    0x0457,  1,   0x0407, /* CYRILLIC CAPITAL LETTER YI */
 /*1023*/    0x0458,  1,   0x0408, /* CYRILLIC CAPITAL LETTER JE */
 /*1026*/    0x0459,  1,   0x0409, /* CYRILLIC CAPITAL LETTER LJE */
 /*1029*/    0x045a,  1,   0x040a, /* CYRILLIC CAPITAL LETTER NJE */
 /*1032*/    0x045b,  1,   0x040b, /* CYRILLIC CAPITAL LETTER TSHE */
 /*1035*/    0x045c,  1,   0x040c, /* CYRILLIC CAPITAL LETTER KJE */
 /*1038*/    0x045d,  1,   0x040d, /* CYRILLIC CAPITAL LETTER I WITH GR.. */
 /*1041*/    0x045e,  1,   0x040e, /* CYRILLIC CAPITAL LETTER SHORT U */
 /*1044*/    0x045f,  1,   0x040f, /* CYRILLIC CAPITAL LETTER DZHE */
 /*1047*/    0x0461,  1,   0x0460, /* CYRILLIC CAPITAL LETTER OMEGA */
 /*1050*/    0x0463,  2,   0x0462,   0x1c87, /* CYRILLIC CAPITAL LETTER YAT */
 /*1054*/    0x0465,  1,   0x0464, /* CYRILLIC CAPITAL LETTER IOTIFIED E */
 /*1057*/    0x0467,  1,   0x0466, /* CYRILLIC CAPITAL LETTER LITTLE YUS */
 /*1060*/    0x0469,  1,   0x0468, /* CYRILLIC CAPITAL LETTER IOTIFIED .. */
 /*1063*/    0x046b,  1,   0x046a, /* CYRILLIC CAPITAL LETTER BIG YUS */
 /*1066*/    0x046d,  1,   0x046c, /* CYRILLIC CAPITAL LETTER IOTIFIED .. */
 /*1069*/    0x046f,  1,   0x046e, /* CYRILLIC CAPITAL LETTER KSI */
 /*1072*/    0x0471,  1,   0x0470, /* CYRILLIC CAPITAL LETTER PSI */
 /*1075*/    0x0473,  1,   0x0472, /* CYRILLIC CAPITAL LETTER FITA */
 /*1078*/    0x0475,  1,   0x0474, /* CYRILLIC CAPITAL LETTER IZHITSA */
 /*1081*/    0x0477,  1,   0x0476, /* CYRILLIC CAPITAL LETTER IZHITSA W.. */
 /*1084*/    0x0479,  1,   0x0478, /* CYRILLIC CAPITAL LETTER UK */
 /*1087*/    0x047b,  1,   0x047a, /* CYRILLIC CAPITAL LETTER ROUND OME.. */
 /*1090*/    0x047d,  1,   0x047c, /* CYRILLIC CAPITAL LETTER OMEGA WIT.. */
 /*1093*/    0x047f,  1,   0x047e, /* CYRILLIC CAPITAL LETTER OT */
 /*1096*/    0x0481,  1,   0x0480, /* CYRILLIC CAPITAL LETTER KOPPA */
 /*1099*/    0x048b,  1,   0x048a, /* CYRILLIC CAPITAL LETTER SHORT I W.. */
 /*1102*/    0x048d,  1,   0x048c, /* CYRILLIC CAPITAL LETTER SEMISOFT .. */
 /*1105*/    0x048f,  1,   0x048e, /* CYRILLIC CAPITAL LETTER ER WITH T.. */
 /*1108*/    0x0491,  1,   0x0490, /* CYRILLIC CAPITAL LETTER GHE WITH .. */
 /*1111*/    0x0493,  1,   0x0492, /* CYRILLIC CAPITAL LETTER GHE WITH .. */
 /*1114*/    0x0495,  1,   0x0494, /* CYRILLIC CAPITAL LETTER GHE WITH .. */
 /*1117*/    0x0497,  1,   0x0496, /* CYRILLIC CAPITAL LETTER ZHE WITH .. */
 /*1120*/    0x0499,  1,   0x0498, /* CYRILLIC CAPITAL LETTER ZE WITH D.. */
 /*1123*/    0x049b,  1,   0x049a, /* CYRILLIC CAPITAL LETTER KA WITH D.. */
 /*1126*/    0x049d,  1,   0x049c, /* CYRILLIC CAPITAL LETTER KA WITH V.. */
 /*1129*/    0x049f,  1,   0x049e, /* CYRILLIC CAPITAL LETTER KA WITH S.. */
 /*1132*/    0x04a1,  1,   0x04a0, /* CYRILLIC CAPITAL LETTER BASHKIR KA */
 /*1135*/    0x04a3,  1,   0x04a2, /* CYRILLIC CAPITAL LETTER EN WITH D.. */
 /*1138*/    0x04a5,  1,   0x04a4, /* CYRILLIC CAPITAL LIGATURE EN GHE */
 /*1141*/    0x04a7,  1,   0x04a6, /* CYRILLIC CAPITAL LETTER PE WITH M.. */
 /*1144*/    0x04a9,  1,   0x04a8, /* CYRILLIC CAPITAL LETTER ABKHASIAN.. */
 /*1147*/    0x04ab,  1,   0x04aa, /* CYRILLIC CAPITAL LETTER ES WITH D.. */
 /*1150*/    0x04ad,  1,   0x04ac, /* CYRILLIC CAPITAL LETTER TE WITH D.. */
 /*1153*/    0x04af,  1,   0x04ae, /* CYRILLIC CAPITAL LETTER STRAIGHT U */
 /*1156*/    0x04b1,  1,   0x04b0, /* CYRILLIC CAPITAL LETTER STRAIGHT .. */
 /*1159*/    0x04b3,  1,   0x04b2, /* CYRILLIC CAPITAL LETTER HA WITH D.. */
 /*1162*/    0x04b5,  1,   0x04b4, /* CYRILLIC CAPITAL LIGATURE TE TSE */
 /*1165*/    0x04b7,  1,   0x04b6, /* CYRILLIC CAPITAL LETTER CHE WITH .. */
 /*1168*/    0x04b9,  1,   0x04b8, /* CYRILLIC CAPITAL LETTER CHE WITH .. */
 /*1171*/    0x04bb,  1,   0x04ba, /* CYRILLIC CAPITAL LETTER SHHA */
 /*1174*/    0x04bd,  1,   0x04bc, /* CYRILLIC CAPITAL LETTER ABKHASIAN.. */
 /*1177*/    0x04bf,  1,   0x04be, /* CYRILLIC CAPITAL LETTER ABKHASIAN.. */
 /*1180*/    0x04c2,  1,   0x04c1, /* CYRILLIC CAPITAL LETTER ZHE WITH .. */
 /*1183*/    0x04c4,  1,   0x04c3, /* CYRILLIC CAPITAL LETTER KA WITH H.. */
 /*1186*/    0x04c6,  1,   0x04c5, /* CYRILLIC CAPITAL LETTER EL WITH T.. */
 /*1189*/    0x04c8,  1,   0x04c7, /* CYRILLIC CAPITAL LETTER EN WITH H.. */
 /*1192*/    0x04ca,  1,   0x04c9, /* CYRILLIC CAPITAL LETTER EN WITH T.. */
 /*1195*/    0x04cc,  1,   0x04cb, /* CYRILLIC CAPITAL LETTER KHAKASSIA.. */
 /*1198*/    0x04ce,  1,   0x04cd, /* CYRILLIC CAPITAL LETTER EM WITH T.. */
 /*1201*/    0x04cf,  1,   0x04c0, /* CYRILLIC LETTER PALOCHKA */
 /*1204*/    0x04d1,  1,   0x04d0, /* CYRILLIC CAPITAL LETTER A WITH BR.. */
 /*1207*/    0x04d3,  1,   0x04d2, /* CYRILLIC CAPITAL LETTER A WITH DI.. */
 /*1210*/    0x04d5,  1,   0x04d4, /* CYRILLIC CAPITAL LIGATURE A IE */
 /*1213*/    0x04d7,  1,   0x04d6, /* CYRILLIC CAPITAL LETTER IE WITH B.. */
 /*1216*/    0x04d9,  1,   0x04d8, /* CYRILLIC CAPITAL LETTER SCHWA */
 /*1219*/    0x04db,  1,   0x04da, /* CYRILLIC CAPITAL LETTER SCHWA WIT.. */
 /*1222*/    0x04dd,  1,   0x04dc, /* CYRILLIC CAPITAL LETTER ZHE WITH .. */
 /*1225*/    0x04df,  1,   0x04de, /* CYRILLIC CAPITAL LETTER ZE WITH D.. */
 /*1228*/    0x04e1,  1,   0x04e0, /* CYRILLIC CAPITAL LETTER ABKHASIAN.. */
 /*1231*/    0x04e3,  1,   0x04e2, /* CYRILLIC CAPITAL LETTER I WITH MA.. */
 /*1234*/    0x04e5,  1,   0x04e4, /* CYRILLIC CAPITAL LETTER I WITH DI.. */
 /*1237*/    0x04e7,  1,   0x04e6, /* CYRILLIC CAPITAL LETTER O WITH DI.. */
 /*1240*/    0x04e9,  1,   0x04e8, /* CYRILLIC CAPITAL LETTER BARRED O */
 /*1243*/    0x04eb,  1,   0x04ea, /* CYRILLIC CAPITAL LETTER BARRED O .. */
 /*1246*/    0x04ed,  1,   0x04ec, /* CYRILLIC CAPITAL LETTER E WITH DI.. */
 /*1249*/    0x04ef,  1,   0x04ee, /* CYRILLIC CAPITAL LETTER U WITH MA.. */
 /*1252*/    0x04f1,  1,   0x04f0, /* CYRILLIC CAPITAL LETTER U WITH DI.. */
 /*1255*/    0x04f3,  1,   0x04f2, /* CYRILLIC CAPITAL LETTER U WITH DO.. */
 /*1258*/    0x04f5,  1,   0x04f4, /* CYRILLIC CAPITAL LETTER CHE WITH .. */
 /*1261*/    0x04f7,  1,   0x04f6, /* CYRILLIC CAPITAL LETTER GHE WITH .. */
 /*1264*/    0x04f9,  1,   0x04f8, /* CYRILLIC CAPITAL LETTER YERU WITH.. */
 /*1267*/    0x04fb,  1,   0x04fa, /* CYRILLIC CAPITAL LETTER GHE WITH .. */
 /*1270*/    0x04fd,  1,   0x04fc, /* CYRILLIC CAPITAL LETTER HA WITH H.. */
 /*1273*/    0x04ff,  1,   0x04fe, /* CYRILLIC CAPITAL LETTER HA WITH S.. */
 /*1276*/    0x0501,  1,   0x0500, /* CYRILLIC CAPITAL LETTER KOMI DE */
 /*1279*/    0x0503,  1,   0x0502, /* CYRILLIC CAPITAL LETTER KOMI DJE */
 /*1282*/    0x0505,  1,   0x0504, /* CYRILLIC CAPITAL LETTER KOMI ZJE */
 /*1285*/    0x0507,  1,   0x0506, /* CYRILLIC CAPITAL LETTER KOMI DZJE */
 /*1288*/    0x0509,  1,   0x0508, /* CYRILLIC CAPITAL LETTER KOMI LJE */
 /*1291*/    0x050b,  1,   0x050a, /* CYRILLIC CAPITAL LETTER KOMI NJE */
 /*1294*/    0x050d,  1,   0x050c, /* CYRILLIC CAPITAL LETTER KOMI SJE */
 /*1297*/    0x050f,  1,   0x050e, /* CYRILLIC CAPITAL LETTER KOMI TJE */
 /*1300*/    0x0511,  1,   0x0510, /* CYRILLIC CAPITAL LETTER REVERSED .. */
 /*1303*/    0x0513,  1,   0x0512, /* CYRILLIC CAPITAL LETTER EL WITH H.. */
 /*1306*/    0x0515,  1,   0x0514, /* CYRILLIC CAPITAL LETTER LHA */
 /*1309*/    0x0517,  1,   0x0516, /* CYRILLIC CAPITAL LETTER RHA */
 /*1312*/    0x0519,  1,   0x0518, /* CYRILLIC CAPITAL LETTER YAE */
 /*1315*/    0x051b,  1,   0x051a, /* CYRILLIC CAPITAL LETTER QA */
 /*1318*/    0x051d,  1,   0x051c, /* CYRILLIC CAPITAL LETTER WE */
 /*1321*/    0x051f,  1,   0x051e, /* CYRILLIC CAPITAL LETTER ALEUT KA */
 /*1324*/    0x0521,  1,   0x0520, /* CYRILLIC CAPITAL LETTER EL WITH M.. */
 /*1327*/    0x0523,  1,   0x0522, /* CYRILLIC CAPITAL LETTER EN WITH M.. */
 /*1330*/    0x0525,  1,   0x0524, /* CYRILLIC CAPITAL LETTER PE WITH D.. */
 /*1333*/    0x0527,  1,   0x0526, /* CYRILLIC CAPITAL LETTER SHHA WITH.. */
 /*1336*/    0x0529,  1,   0x0528, /* CYRILLIC CAPITAL LETTER EN WITH L.. */
 /*1339*/    0x052b,  1,   0x052a, /* CYRILLIC CAPITAL LETTER DZZHE */
 /*1342*/    0x052d,  1,   0x052c, /* CYRILLIC CAPITAL LETTER DCHE */
 /*1345*/    0x052f,  1,   0x052e, /* CYRILLIC CAPITAL LETTER EL WITH D.. */
 /*1348*/    0x0561,  1,   0x0531, /* ARMENIAN CAPITAL LETTER AYB */
 /*1351*/    0x0562,  1,   0x0532, /* ARMENIAN CAPITAL LETTER BEN */
 /*1354*/    0x0563,  1,   0x0533, /* ARMENIAN CAPITAL LETTER GIM */
 /*1357*/    0x0564,  1,   0x0534, /* ARMENIAN CAPITAL LETTER DA */
 /*1360*/    0x0565,  1,   0x0535, /* ARMENIAN CAPITAL LETTER ECH */
 /*1363*/    0x0566,  1,   0x0536, /* ARMENIAN CAPITAL LETTER ZA */
 /*1366*/    0x0567,  1,   0x0537, /* ARMENIAN CAPITAL LETTER EH */
 /*1369*/    0x0568,  1,   0x0538, /* ARMENIAN CAPITAL LETTER ET */
 /*1372*/    0x0569,  1,   0x0539, /* ARMENIAN CAPITAL LETTER TO */
 /*1375*/    0x056a,  1,   0x053a, /* ARMENIAN CAPITAL LETTER ZHE */
 /*1378*/    0x056b,  1,   0x053b, /* ARMENIAN CAPITAL LETTER INI */
 /*1381*/    0x056c,  1,   0x053c, /* ARMENIAN CAPITAL LETTER LIWN */
 /*1384*/    0x056d,  1,   0x053d, /* ARMENIAN CAPITAL LETTER XEH */
 /*1387*/    0x056e,  1,   0x053e, /* ARMENIAN CAPITAL LETTER CA */
 /*1390*/    0x056f,  1,   0x053f, /* ARMENIAN CAPITAL LETTER KEN */
 /*1393*/    0x0570,  1,   0x0540, /* ARMENIAN CAPITAL LETTER HO */
 /*1396*/    0x0571,  1,   0x0541, /* ARMENIAN CAPITAL LETTER JA */
 /*1399*/    0x0572,  1,   0x0542, /* ARMENIAN CAPITAL LETTER GHAD */
 /*1402*/    0x0573,  1,   0x0543, /* ARMENIAN CAPITAL LETTER CHEH */
 /*1405*/    0x0574,  1,   0x0544, /* ARMENIAN CAPITAL LETTER MEN */
 /*1408*/    0x0575,  1,   0x0545, /* ARMENIAN CAPITAL LETTER YI */
 /*1411*/    0x0576,  1,   0x0546, /* ARMENIAN CAPITAL LETTER NOW */
 /*1414*/    0x0577,  1,   0x0547, /* ARMENIAN CAPITAL LETTER SHA */
 /*1417*/    0x0578,  1,   0x0548, /* ARMENIAN CAPITAL LETTER VO */
 /*1420*/    0x0579,  1,   0x0549, /* ARMENIAN CAPITAL LETTER CHA */
 /*1423*/    0x057a,  1,   0x054a, /* ARMENIAN CAPITAL LETTER PEH */
 /*1426*/    0x057b,  1,   0x054b, /* ARMENIAN CAPITAL LETTER JHEH */
 /*1429*/    0x057c,  1,   0x054c, /* ARMENIAN CAPITAL LETTER RA */
 /*1432*/    0x057d,  1,   0x054d, /* ARMENIAN CAPITAL LETTER SEH */
 /*1435*/    0x057e,  1,   0x054e, /* ARMENIAN CAPITAL LETTER VEW */
 /*1438*/    0x057f,  1,   0x054f, /* ARMENIAN CAPITAL LETTER TIWN */
 /*1441*/    0x0580,  1,   0x0550, /* ARMENIAN CAPITAL LETTER REH */
 /*1444*/    0x0581,  1,   0x0551, /* ARMENIAN CAPITAL LETTER CO */
 /*1447*/    0x0582,  1,   0x0552, /* ARMENIAN CAPITAL LETTER YIWN */
 /*1450*/    0x0583,  1,   0x0553, /* ARMENIAN CAPITAL LETTER PIWR */
 /*1453*/    0x0584,  1,   0x0554, /* ARMENIAN CAPITAL LETTER KEH */
 /*1456*/    0x0585,  1,   0x0555, /* ARMENIAN CAPITAL LETTER OH */
 /*1459*/    0x0586,  1,   0x0556, /* ARMENIAN CAPITAL LETTER FEH */
 /*1462*/    0x10d0,  1,   0x1c90, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1465*/    0x10d1,  1,   0x1c91, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1468*/    0x10d2,  1,   0x1c92, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1471*/    0x10d3,  1,   0x1c93, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1474*/    0x10d4,  1,   0x1c94, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1477*/    0x10d5,  1,   0x1c95, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1480*/    0x10d6,  1,   0x1c96, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1483*/    0x10d7,  1,   0x1c97, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1486*/    0x10d8,  1,   0x1c98, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1489*/    0x10d9,  1,   0x1c99, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1492*/    0x10da,  1,   0x1c9a, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1495*/    0x10db,  1,   0x1c9b, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1498*/    0x10dc,  1,   0x1c9c, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1501*/    0x10dd,  1,   0x1c9d, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1504*/    0x10de,  1,   0x1c9e, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1507*/    0x10df,  1,   0x1c9f, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1510*/    0x10e0,  1,   0x1ca0, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1513*/    0x10e1,  1,   0x1ca1, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1516*/    0x10e2,  1,   0x1ca2, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1519*/    0x10e3,  1,   0x1ca3, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1522*/    0x10e4,  1,   0x1ca4, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1525*/    0x10e5,  1,   0x1ca5, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1528*/    0x10e6,  1,   0x1ca6, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1531*/    0x10e7,  1,   0x1ca7, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1534*/    0x10e8,  1,   0x1ca8, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1537*/    0x10e9,  1,   0x1ca9, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1540*/    0x10ea,  1,   0x1caa, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1543*/    0x10eb,  1,   0x1cab, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1546*/    0x10ec,  1,   0x1cac, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1549*/    0x10ed,  1,   0x1cad, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1552*/    0x10ee,  1,   0x1cae, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1555*/    0x10ef,  1,   0x1caf, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1558*/    0x10f0,  1,   0x1cb0, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1561*/    0x10f1,  1,   0x1cb1, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1564*/    0x10f2,  1,   0x1cb2, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1567*/    0x10f3,  1,   0x1cb3, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1570*/    0x10f4,  1,   0x1cb4, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1573*/    0x10f5,  1,   0x1cb5, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1576*/    0x10f6,  1,   0x1cb6, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1579*/    0x10f7,  1,   0x1cb7, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1582*/    0x10f8,  1,   0x1cb8, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1585*/    0x10f9,  1,   0x1cb9, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1588*/    0x10fa,  1,   0x1cba, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1591*/    0x10fd,  1,   0x1cbd, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1594*/    0x10fe,  1,   0x1cbe, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1597*/    0x10ff,  1,   0x1cbf, /* GEORGIAN MTAVRULI CAPITAL LETTER .. */
 /*1600*/    0x13a0,  1,   0xab70, /* CHEROKEE SMALL LETTER A */
 /*1603*/    0x13a1,  1,   0xab71, /* CHEROKEE SMALL LETTER E */
 /*1606*/    0x13a2,  1,   0xab72, /* CHEROKEE SMALL LETTER I */
 /*1609*/    0x13a3,  1,   0xab73, /* CHEROKEE SMALL LETTER O */
 /*1612*/    0x13a4,  1,   0xab74, /* CHEROKEE SMALL LETTER U */
 /*1615*/    0x13a5,  1,   0xab75, /* CHEROKEE SMALL LETTER V */
 /*1618*/    0x13a6,  1,   0xab76, /* CHEROKEE SMALL LETTER GA */
 /*1621*/    0x13a7,  1,   0xab77, /* CHEROKEE SMALL LETTER KA */
 /*1624*/    0x13a8,  1,   0xab78, /* CHEROKEE SMALL LETTER GE */
 /*1627*/    0x13a9,  1,   0xab79, /* CHEROKEE SMALL LETTER GI */
 /*1630*/    0x13aa,  1,   0xab7a, /* CHEROKEE SMALL LETTER GO */
 /*1633*/    0x13ab,  1,   0xab7b, /* CHEROKEE SMALL LETTER GU */
 /*1636*/    0x13ac,  1,   0xab7c, /* CHEROKEE SMALL LETTER GV */
 /*1639*/    0x13ad,  1,   0xab7d, /* CHEROKEE SMALL LETTER HA */
 /*1642*/    0x13ae,  1,   0xab7e, /* CHEROKEE SMALL LETTER HE */
 /*1645*/    0x13af,  1,   0xab7f, /* CHEROKEE SMALL LETTER HI */
 /*1648*/    0x13b0,  1,   0xab80, /* CHEROKEE SMALL LETTER HO */
 /*1651*/    0x13b1,  1,   0xab81, /* CHEROKEE SMALL LETTER HU */
 /*1654*/    0x13b2,  1,   0xab82, /* CHEROKEE SMALL LETTER HV */
 /*1657*/    0x13b3,  1,   0xab83, /* CHEROKEE SMALL LETTER LA */
 /*1660*/    0x13b4,  1,   0xab84, /* CHEROKEE SMALL LETTER LE */
 /*1663*/    0x13b5,  1,   0xab85, /* CHEROKEE SMALL LETTER LI */
 /*1666*/    0x13b6,  1,   0xab86, /* CHEROKEE SMALL LETTER LO */
 /*1669*/    0x13b7,  1,   0xab87, /* CHEROKEE SMALL LETTER LU */
 /*1672*/    0x13b8,  1,   0xab88, /* CHEROKEE SMALL LETTER LV */
 /*1675*/    0x13b9,  1,   0xab89, /* CHEROKEE SMALL LETTER MA */
 /*1678*/    0x13ba,  1,   0xab8a, /* CHEROKEE SMALL LETTER ME */
 /*1681*/    0x13bb,  1,   0xab8b, /* CHEROKEE SMALL LETTER MI */
 /*1684*/    0x13bc,  1,   0xab8c, /* CHEROKEE SMALL LETTER MO */
 /*1687*/    0x13bd,  1,   0xab8d, /* CHEROKEE SMALL LETTER MU */
 /*1690*/    0x13be,  1,   0xab8e, /* CHEROKEE SMALL LETTER NA */
 /*1693*/    0x13bf,  1,   0xab8f, /* CHEROKEE SMALL LETTER HNA */
 /*1696*/    0x13c0,  1,   0xab90, /* CHEROKEE SMALL LETTER NAH */
 /*1699*/    0x13c1,  1,   0xab91, /* CHEROKEE SMALL LETTER NE */
 /*1702*/    0x13c2,  1,   0xab92, /* CHEROKEE SMALL LETTER NI */
 /*1705*/    0x13c3,  1,   0xab93, /* CHEROKEE SMALL LETTER NO */
 /*1708*/    0x13c4,  1,   0xab94, /* CHEROKEE SMALL LETTER NU */
 /*1711*/    0x13c5,  1,   0xab95, /* CHEROKEE SMALL LETTER NV */
 /*1714*/    0x13c6,  1,   0xab96, /* CHEROKEE SMALL LETTER QUA */
 /*1717*/    0x13c7,  1,   0xab97, /* CHEROKEE SMALL LETTER QUE */
 /*1720*/    0x13c8,  1,   0xab98, /* CHEROKEE SMALL LETTER QUI */
 /*1723*/    0x13c9,  1,   0xab99, /* CHEROKEE SMALL LETTER QUO */
 /*1726*/    0x13ca,  1,   0xab9a, /* CHEROKEE SMALL LETTER QUU */
 /*1729*/    0x13cb,  1,   0xab9b, /* CHEROKEE SMALL LETTER QUV */
 /*1732*/    0x13cc,  1,   0xab9c, /* CHEROKEE SMALL LETTER SA */
 /*1735*/    0x13cd,  1,   0xab9d, /* CHEROKEE SMALL LETTER S */
 /*1738*/    0x13ce,  1,   0xab9e, /* CHEROKEE SMALL LETTER SE */
 /*1741*/    0x13cf,  1,   0xab9f, /* CHEROKEE SMALL LETTER SI */
 /*1744*/    0x13d0,  1,   0xaba0, /* CHEROKEE SMALL LETTER SO */
 /*1747*/    0x13d1,  1,   0xaba1, /* CHEROKEE SMALL LETTER SU */
 /*1750*/    0x13d2,  1,   0xaba2, /* CHEROKEE SMALL LETTER SV */
 /*1753*/    0x13d3,  1,   0xaba3, /* CHEROKEE SMALL LETTER DA */
 /*1756*/    0x13d4,  1,   0xaba4, /* CHEROKEE SMALL LETTER TA */
 /*1759*/    0x13d5,  1,   0xaba5, /* CHEROKEE SMALL LETTER DE */
 /*1762*/    0x13d6,  1,   0xaba6, /* CHEROKEE SMALL LETTER TE */
 /*1765*/    0x13d7,  1,   0xaba7, /* CHEROKEE SMALL LETTER DI */
 /*1768*/    0x13d8,  1,   0xaba8, /* CHEROKEE SMALL LETTER TI */
 /*1771*/    0x13d9,  1,   0xaba9, /* CHEROKEE SMALL LETTER DO */
 /*1774*/    0x13da,  1,   0xabaa, /* CHEROKEE SMALL LETTER DU */
 /*1777*/    0x13db,  1,   0xabab, /* CHEROKEE SMALL LETTER DV */
 /*1780*/    0x13dc,  1,   0xabac, /* CHEROKEE SMALL LETTER DLA */
 /*1783*/    0x13dd,  1,   0xabad, /* CHEROKEE SMALL LETTER TLA */
 /*1786*/    0x13de,  1,   0xabae, /* CHEROKEE SMALL LETTER TLE */
 /*1789*/    0x13df,  1,   0xabaf, /* CHEROKEE SMALL LETTER TLI */
 /*1792*/    0x13e0,  1,   0xabb0, /* CHEROKEE SMALL LETTER TLO */
 /*1795*/    0x13e1,  1,   0xabb1, /* CHEROKEE SMALL LETTER TLU */
 /*1798*/    0x13e2,  1,   0xabb2, /* CHEROKEE SMALL LETTER TLV */
 /*1801*/    0x13e3,  1,   0xabb3, /* CHEROKEE SMALL LETTER TSA */
 /*1804*/    0x13e4,  1,   0xabb4, /* CHEROKEE SMALL LETTER TSE */
 /*1807*/    0x13e5,  1,   0xabb5, /* CHEROKEE SMALL LETTER TSI */
 /*1810*/    0x13e6,  1,   0xabb6, /* CHEROKEE SMALL LETTER TSO */
 /*1813*/    0x13e7,  1,   0xabb7, /* CHEROKEE SMALL LETTER TSU */
 /*1816*/    0x13e8,  1,   0xabb8, /* CHEROKEE SMALL LETTER TSV */
 /*1819*/    0x13e9,  1,   0xabb9, /* CHEROKEE SMALL LETTER WA */
 /*1822*/    0x13ea,  1,   0xabba, /* CHEROKEE SMALL LETTER WE */
 /*1825*/    0x13eb,  1,   0xabbb, /* CHEROKEE SMALL LETTER WI */
 /*1828*/    0x13ec,  1,   0xabbc, /* CHEROKEE SMALL LETTER WO */
 /*1831*/    0x13ed,  1,   0xabbd, /* CHEROKEE SMALL LETTER WU */
 /*1834*/    0x13ee,  1,   0xabbe, /* CHEROKEE SMALL LETTER WV */
 /*1837*/    0x13ef,  1,   0xabbf, /* CHEROKEE SMALL LETTER YA */
 /*1840*/    0x13f0,  1,   0x13f8, /* CHEROKEE SMALL LETTER YE */
 /*1843*/    0x13f1,  1,   0x13f9, /* CHEROKEE SMALL LETTER YI */
 /*1846*/    0x13f2,  1,   0x13fa, /* CHEROKEE SMALL LETTER YO */
 /*1849*/    0x13f3,  1,   0x13fb, /* CHEROKEE SMALL LETTER YU */
 /*1852*/    0x13f4,  1,   0x13fc, /* CHEROKEE SMALL LETTER YV */
 /*1855*/    0x13f5,  1,   0x13fd, /* CHEROKEE SMALL LETTER MV */
 /*1858*/    0x1d79,  1,   0xa77d, /* LATIN CAPITAL LETTER INSULAR G */
 /*1861*/    0x1d7d,  1,   0x2c63, /* LATIN CAPITAL LETTER P WITH STROKE */
 /*1864*/    0x1d8e,  1,   0xa7c6, /* LATIN CAPITAL LETTER Z WITH PALAT.. */
 /*1867*/    0x1e01,  1,   0x1e00, /* LATIN CAPITAL LETTER A WITH RING .. */
 /*1870*/    0x1e03,  1,   0x1e02, /* LATIN CAPITAL LETTER B WITH DOT A.. */
 /*1873*/    0x1e05,  1,   0x1e04, /* LATIN CAPITAL LETTER B WITH DOT B.. */
 /*1876*/    0x1e07,  1,   0x1e06, /* LATIN CAPITAL LETTER B WITH LINE .. */
 /*1879*/    0x1e09,  1,   0x1e08, /* LATIN CAPITAL LETTER C WITH CEDIL.. */
 /*1882*/    0x1e0b,  1,   0x1e0a, /* LATIN CAPITAL LETTER D WITH DOT A.. */
 /*1885*/    0x1e0d,  1,   0x1e0c, /* LATIN CAPITAL LETTER D WITH DOT B.. */
 /*1888*/    0x1e0f,  1,   0x1e0e, /* LATIN CAPITAL LETTER D WITH LINE .. */
 /*1891*/    0x1e11,  1,   0x1e10, /* LATIN CAPITAL LETTER D WITH CEDIL.. */
 /*1894*/    0x1e13,  1,   0x1e12, /* LATIN CAPITAL LETTER D WITH CIRCU.. */
 /*1897*/    0x1e15,  1,   0x1e14, /* LATIN CAPITAL LETTER E WITH MACRO.. */
 /*1900*/    0x1e17,  1,   0x1e16, /* LATIN CAPITAL LETTER E WITH MACRO.. */
 /*1903*/    0x1e19,  1,   0x1e18, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /*1906*/    0x1e1b,  1,   0x1e1a, /* LATIN CAPITAL LETTER E WITH TILDE.. */
 /*1909*/    0x1e1d,  1,   0x1e1c, /* LATIN CAPITAL LETTER E WITH CEDIL.. */
 /*1912*/    0x1e1f,  1,   0x1e1e, /* LATIN CAPITAL LETTER F WITH DOT A.. */
 /*1915*/    0x1e21,  1,   0x1e20, /* LATIN CAPITAL LETTER G WITH MACRON */
 /*1918*/    0x1e23,  1,   0x1e22, /* LATIN CAPITAL LETTER H WITH DOT A.. */
 /*1921*/    0x1e25,  1,   0x1e24, /* LATIN CAPITAL LETTER H WITH DOT B.. */
 /*1924*/    0x1e27,  1,   0x1e26, /* LATIN CAPITAL LETTER H WITH DIAER.. */
 /*1927*/    0x1e29,  1,   0x1e28, /* LATIN CAPITAL LETTER H WITH CEDIL.. */
 /*1930*/    0x1e2b,  1,   0x1e2a, /* LATIN CAPITAL LETTER H WITH BREVE.. */
 /*1933*/    0x1e2d,  1,   0x1e2c, /* LATIN CAPITAL LETTER I WITH TILDE.. */
 /*1936*/    0x1e2f,  1,   0x1e2e, /* LATIN CAPITAL LETTER I WITH DIAER.. */
 /*1939*/    0x1e31,  1,   0x1e30, /* LATIN CAPITAL LETTER K WITH ACUTE */
 /*1942*/    0x1e33,  1,   0x1e32, /* LATIN CAPITAL LETTER K WITH DOT B.. */
 /*1945*/    0x1e35,  1,   0x1e34, /* LATIN CAPITAL LETTER K WITH LINE .. */
 /*1948*/    0x1e37,  1,   0x1e36, /* LATIN CAPITAL LETTER L WITH DOT B.. */
 /*1951*/    0x1e39,  1,   0x1e38, /* LATIN CAPITAL LETTER L WITH DOT B.. */
 /*1954*/    0x1e3b,  1,   0x1e3a, /* LATIN CAPITAL LETTER L WITH LINE .. */
 /*1957*/    0x1e3d,  1,   0x1e3c, /* LATIN CAPITAL LETTER L WITH CIRCU.. */
 /*1960*/    0x1e3f,  1,   0x1e3e, /* LATIN CAPITAL LETTER M WITH ACUTE */
 /*1963*/    0x1e41,  1,   0x1e40, /* LATIN CAPITAL LETTER M WITH DOT A.. */
 /*1966*/    0x1e43,  1,   0x1e42, /* LATIN CAPITAL LETTER M WITH DOT B.. */
 /*1969*/    0x1e45,  1,   0x1e44, /* LATIN CAPITAL LETTER N WITH DOT A.. */
 /*1972*/    0x1e47,  1,   0x1e46, /* LATIN CAPITAL LETTER N WITH DOT B.. */
 /*1975*/    0x1e49,  1,   0x1e48, /* LATIN CAPITAL LETTER N WITH LINE .. */
 /*1978*/    0x1e4b,  1,   0x1e4a, /* LATIN CAPITAL LETTER N WITH CIRCU.. */
 /*1981*/    0x1e4d,  1,   0x1e4c, /* LATIN CAPITAL LETTER O WITH TILDE.. */
 /*1984*/    0x1e4f,  1,   0x1e4e, /* LATIN CAPITAL LETTER O WITH TILDE.. */
 /*1987*/    0x1e51,  1,   0x1e50, /* LATIN CAPITAL LETTER O WITH MACRO.. */
 /*1990*/    0x1e53,  1,   0x1e52, /* LATIN CAPITAL LETTER O WITH MACRO.. */
 /*1993*/    0x1e55,  1,   0x1e54, /* LATIN CAPITAL LETTER P WITH ACUTE */
 /*1996*/    0x1e57,  1,   0x1e56, /* LATIN CAPITAL LETTER P WITH DOT A.. */
 /*1999*/    0x1e59,  1,   0x1e58, /* LATIN CAPITAL LETTER R WITH DOT A.. */
 /*2002*/    0x1e5b,  1,   0x1e5a, /* LATIN CAPITAL LETTER R WITH DOT B.. */
 /*2005*/    0x1e5d,  1,   0x1e5c, /* LATIN CAPITAL LETTER R WITH DOT B.. */
 /*2008*/    0x1e5f,  1,   0x1e5e, /* LATIN CAPITAL LETTER R WITH LINE .. */
 /*2011*/    0x1e61,  2,   0x1e60,   0x1e9b, /* LATIN CAPITAL LETTER S WITH DOT A.. */
 /*2015*/    0x1e63,  1,   0x1e62, /* LATIN CAPITAL LETTER S WITH DOT B.. */
 /*2018*/    0x1e65,  1,   0x1e64, /* LATIN CAPITAL LETTER S WITH ACUTE.. */
 /*2021*/    0x1e67,  1,   0x1e66, /* LATIN CAPITAL LETTER S WITH CARON.. */
 /*2024*/    0x1e69,  1,   0x1e68, /* LATIN CAPITAL LETTER S WITH DOT B.. */
 /*2027*/    0x1e6b,  1,   0x1e6a, /* LATIN CAPITAL LETTER T WITH DOT A.. */
 /*2030*/    0x1e6d,  1,   0x1e6c, /* LATIN CAPITAL LETTER T WITH DOT B.. */
 /*2033*/    0x1e6f,  1,   0x1e6e, /* LATIN CAPITAL LETTER T WITH LINE .. */
 /*2036*/    0x1e71,  1,   0x1e70, /* LATIN CAPITAL LETTER T WITH CIRCU.. */
 /*2039*/    0x1e73,  1,   0x1e72, /* LATIN CAPITAL LETTER U WITH DIAER.. */
 /*2042*/    0x1e75,  1,   0x1e74, /* LATIN CAPITAL LETTER U WITH TILDE.. */
 /*2045*/    0x1e77,  1,   0x1e76, /* LATIN CAPITAL LETTER U WITH CIRCU.. */
 /*2048*/    0x1e79,  1,   0x1e78, /* LATIN CAPITAL LETTER U WITH TILDE.. */
 /*2051*/    0x1e7b,  1,   0x1e7a, /* LATIN CAPITAL LETTER U WITH MACRO.. */
 /*2054*/    0x1e7d,  1,   0x1e7c, /* LATIN CAPITAL LETTER V WITH TILDE */
 /*2057*/    0x1e7f,  1,   0x1e7e, /* LATIN CAPITAL LETTER V WITH DOT B.. */
 /*2060*/    0x1e81,  1,   0x1e80, /* LATIN CAPITAL LETTER W WITH GRAVE */
 /*2063*/    0x1e83,  1,   0x1e82, /* LATIN CAPITAL LETTER W WITH ACUTE */
 /*2066*/    0x1e85,  1,   0x1e84, /* LATIN CAPITAL LETTER W WITH DIAER.. */
 /*2069*/    0x1e87,  1,   0x1e86, /* LATIN CAPITAL LETTER W WITH DOT A.. */
 /*2072*/    0x1e89,  1,   0x1e88, /* LATIN CAPITAL LETTER W WITH DOT B.. */
 /*2075*/    0x1e8b,  1,   0x1e8a, /* LATIN CAPITAL LETTER X WITH DOT A.. */
 /*2078*/    0x1e8d,  1,   0x1e8c, /* LATIN CAPITAL LETTER X WITH DIAER.. */
 /*2081*/    0x1e8f,  1,   0x1e8e, /* LATIN CAPITAL LETTER Y WITH DOT A.. */
 /*2084*/    0x1e91,  1,   0x1e90, /* LATIN CAPITAL LETTER Z WITH CIRCU.. */
 /*2087*/    0x1e93,  1,   0x1e92, /* LATIN CAPITAL LETTER Z WITH DOT B.. */
 /*2090*/    0x1e95,  1,   0x1e94, /* LATIN CAPITAL LETTER Z WITH LINE .. */
 /*2093*/    0x1ea1,  1,   0x1ea0, /* LATIN CAPITAL LETTER A WITH DOT B.. */
 /*2096*/    0x1ea3,  1,   0x1ea2, /* LATIN CAPITAL LETTER A WITH HOOK .. */
 /*2099*/    0x1ea5,  1,   0x1ea4, /* LATIN CAPITAL LETTER A WITH CIRCU.. */
 /*2102*/    0x1ea7,  1,   0x1ea6, /* LATIN CAPITAL LETTER A WITH CIRCU.. */
 /*2105*/    0x1ea9,  1,   0x1ea8, /* LATIN CAPITAL LETTER A WITH CIRCU.. */
 /*2108*/    0x1eab,  1,   0x1eaa, /* LATIN CAPITAL LETTER A WITH CIRCU.. */
 /*2111*/    0x1ead,  1,   0x1eac, /* LATIN CAPITAL LETTER A WITH CIRCU.. */
 /*2114*/    0x1eaf,  1,   0x1eae, /* LATIN CAPITAL LETTER A WITH BREVE.. */
 /*2117*/    0x1eb1,  1,   0x1eb0, /* LATIN CAPITAL LETTER A WITH BREVE.. */
 /*2120*/    0x1eb3,  1,   0x1eb2, /* LATIN CAPITAL LETTER A WITH BREVE.. */
 /*2123*/    0x1eb5,  1,   0x1eb4, /* LATIN CAPITAL LETTER A WITH BREVE.. */
 /*2126*/    0x1eb7,  1,   0x1eb6, /* LATIN CAPITAL LETTER A WITH BREVE.. */
 /*2129*/    0x1eb9,  1,   0x1eb8, /* LATIN CAPITAL LETTER E WITH DOT B.. */
 /*2132*/    0x1ebb,  1,   0x1eba, /* LATIN CAPITAL LETTER E WITH HOOK .. */
 /*2135*/    0x1ebd,  1,   0x1ebc, /* LATIN CAPITAL LETTER E WITH TILDE */
 /*2138*/    0x1ebf,  1,   0x1ebe, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /*2141*/    0x1ec1,  1,   0x1ec0, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /*2144*/    0x1ec3,  1,   0x1ec2, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /*2147*/    0x1ec5,  1,   0x1ec4, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /*2150*/    0x1ec7,  1,   0x1ec6, /* LATIN CAPITAL LETTER E WITH CIRCU.. */
 /*2153*/    0x1ec9,  1,   0x1ec8, /* LATIN CAPITAL LETTER I WITH HOOK .. */
 /*2156*/    0x1ecb,  1,   0x1eca, /* LATIN CAPITAL LETTER I WITH DOT B.. */
 /*2159*/    0x1ecd,  1,   0x1ecc, /* LATIN CAPITAL LETTER O WITH DOT B.. */
 /*2162*/    0x1ecf,  1,   0x1ece, /* LATIN CAPITAL LETTER O WITH HOOK .. */
 /*2165*/    0x1ed1,  1,   0x1ed0, /* LATIN CAPITAL LETTER O WITH CIRCU.. */
 /*2168*/    0x1ed3,  1,   0x1ed2, /* LATIN CAPITAL LETTER O WITH CIRCU.. */
 /*2171*/    0x1ed5,  1,   0x1ed4, /* LATIN CAPITAL LETTER O WITH CIRCU.. */
 /*2174*/    0x1ed7,  1,   0x1ed6, /* LATIN CAPITAL LETTER O WITH CIRCU.. */
 /*2177*/    0x1ed9,  1,   0x1ed8, /* LATIN CAPITAL LETTER O WITH CIRCU.. */
 /*2180*/    0x1edb,  1,   0x1eda, /* LATIN CAPITAL LETTER O WITH HORN .. */
 /*2183*/    0x1edd,  1,   0x1edc, /* LATIN CAPITAL LETTER O WITH HORN .. */
 /*2186*/    0x1edf,  1,   0x1ede, /* LATIN CAPITAL LETTER O WITH HORN .. */
 /*2189*/    0x1ee1,  1,   0x1ee0, /* LATIN CAPITAL LETTER O WITH HORN .. */
 /*2192*/    0x1ee3,  1,   0x1ee2, /* LATIN CAPITAL LETTER O WITH HORN .. */
 /*2195*/    0x1ee5,  1,   0x1ee4, /* LATIN CAPITAL LETTER U WITH DOT B.. */
 /*2198*/    0x1ee7,  1,   0x1ee6, /* LATIN CAPITAL LETTER U WITH HOOK .. */
 /*2201*/    0x1ee9,  1,   0x1ee8, /* LATIN CAPITAL LETTER U WITH HORN .. */
 /*2204*/    0x1eeb,  1,   0x1eea, /* LATIN CAPITAL LETTER U WITH HORN .. */
 /*2207*/    0x1eed,  1,   0x1eec, /* LATIN CAPITAL LETTER U WITH HORN .. */
 /*2210*/    0x1eef,  1,   0x1eee, /* LATIN CAPITAL LETTER U WITH HORN .. */
 /*2213*/    0x1ef1,  1,   0x1ef0, /* LATIN CAPITAL LETTER U WITH HORN .. */
 /*2216*/    0x1ef3,  1,   0x1ef2, /* LATIN CAPITAL LETTER Y WITH GRAVE */
 /*2219*/    0x1ef5,  1,   0x1ef4, /* LATIN CAPITAL LETTER Y WITH DOT B.. */
 /*2222*/    0x1ef7,  1,   0x1ef6, /* LATIN CAPITAL LETTER Y WITH HOOK .. */
 /*2225*/    0x1ef9,  1,   0x1ef8, /* LATIN CAPITAL LETTER Y WITH TILDE */
 /*2228*/    0x1efb,  1,   0x1efa, /* LATIN CAPITAL LETTER MIDDLE-WELSH.. */
 /*2231*/    0x1efd,  1,   0x1efc, /* LATIN CAPITAL LETTER MIDDLE-WELSH.. */
 /*2234*/    0x1eff,  1,   0x1efe, /* LATIN CAPITAL LETTER Y WITH LOOP */
 /*2237*/    0x1f00,  1,   0x1f08, /* GREEK CAPITAL LETTER ALPHA WITH P.. */
 /*2240*/    0x1f01,  1,   0x1f09, /* GREEK CAPITAL LETTER ALPHA WITH D.. */
 /*2243*/    0x1f02,  1,   0x1f0a, /* GREEK CAPITAL LETTER ALPHA WITH P.. */
 /*2246*/    0x1f03,  1,   0x1f0b, /* GREEK CAPITAL LETTER ALPHA WITH D.. */
 /*2249*/    0x1f04,  1,   0x1f0c, /* GREEK CAPITAL LETTER ALPHA WITH P.. */
 /*2252*/    0x1f05,  1,   0x1f0d, /* GREEK CAPITAL LETTER ALPHA WITH D.. */
 /*2255*/    0x1f06,  1,   0x1f0e, /* GREEK CAPITAL LETTER ALPHA WITH P.. */
 /*2258*/    0x1f07,  1,   0x1f0f, /* GREEK CAPITAL LETTER ALPHA WITH D.. */
 /*2261*/    0x1f10,  1,   0x1f18, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2264*/    0x1f11,  1,   0x1f19, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2267*/    0x1f12,  1,   0x1f1a, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2270*/    0x1f13,  1,   0x1f1b, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2273*/    0x1f14,  1,   0x1f1c, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2276*/    0x1f15,  1,   0x1f1d, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2279*/    0x1f20,  1,   0x1f28, /* GREEK CAPITAL LETTER ETA WITH PSI.. */
 /*2282*/    0x1f21,  1,   0x1f29, /* GREEK CAPITAL LETTER ETA WITH DAS.. */
 /*2285*/    0x1f22,  1,   0x1f2a, /* GREEK CAPITAL LETTER ETA WITH PSI.. */
 /*2288*/    0x1f23,  1,   0x1f2b, /* GREEK CAPITAL LETTER ETA WITH DAS.. */
 /*2291*/    0x1f24,  1,   0x1f2c, /* GREEK CAPITAL LETTER ETA WITH PSI.. */
 /*2294*/    0x1f25,  1,   0x1f2d, /* GREEK CAPITAL LETTER ETA WITH DAS.. */
 /*2297*/    0x1f26,  1,   0x1f2e, /* GREEK CAPITAL LETTER ETA WITH PSI.. */
 /*2300*/    0x1f27,  1,   0x1f2f, /* GREEK CAPITAL LETTER ETA WITH DAS.. */
 /*2303*/    0x1f30,  1,   0x1f38, /* GREEK CAPITAL LETTER IOTA WITH PS.. */
 /*2306*/    0x1f31,  1,   0x1f39, /* GREEK CAPITAL LETTER IOTA WITH DA.. */
 /*2309*/    0x1f32,  1,   0x1f3a, /* GREEK CAPITAL LETTER IOTA WITH PS.. */
 /*2312*/    0x1f33,  1,   0x1f3b, /* GREEK CAPITAL LETTER IOTA WITH DA.. */
 /*2315*/    0x1f34,  1,   0x1f3c, /* GREEK CAPITAL LETTER IOTA WITH PS.. */
 /*2318*/    0x1f35,  1,   0x1f3d, /* GREEK CAPITAL LETTER IOTA WITH DA.. */
 /*2321*/    0x1f36,  1,   0x1f3e, /* GREEK CAPITAL LETTER IOTA WITH PS.. */
 /*2324*/    0x1f37,  1,   0x1f3f, /* GREEK CAPITAL LETTER IOTA WITH DA.. */
 /*2327*/    0x1f40,  1,   0x1f48, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2330*/    0x1f41,  1,   0x1f49, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2333*/    0x1f42,  1,   0x1f4a, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2336*/    0x1f43,  1,   0x1f4b, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2339*/    0x1f44,  1,   0x1f4c, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2342*/    0x1f45,  1,   0x1f4d, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2345*/    0x1f51,  1,   0x1f59, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2348*/    0x1f53,  1,   0x1f5b, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2351*/    0x1f55,  1,   0x1f5d, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2354*/    0x1f57,  1,   0x1f5f, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2357*/    0x1f60,  1,   0x1f68, /* GREEK CAPITAL LETTER OMEGA WITH P.. */
 /*2360*/    0x1f61,  1,   0x1f69, /* GREEK CAPITAL LETTER OMEGA WITH D.. */
 /*2363*/    0x1f62,  1,   0x1f6a, /* GREEK CAPITAL LETTER OMEGA WITH P.. */
 /*2366*/    0x1f63,  1,   0x1f6b, /* GREEK CAPITAL LETTER OMEGA WITH D.. */
 /*2369*/    0x1f64,  1,   0x1f6c, /* GREEK CAPITAL LETTER OMEGA WITH P.. */
 /*2372*/    0x1f65,  1,   0x1f6d, /* GREEK CAPITAL LETTER OMEGA WITH D.. */
 /*2375*/    0x1f66,  1,   0x1f6e, /* GREEK CAPITAL LETTER OMEGA WITH P.. */
 /*2378*/    0x1f67,  1,   0x1f6f, /* GREEK CAPITAL LETTER OMEGA WITH D.. */
 /*2381*/    0x1f70,  1,   0x1fba, /* GREEK CAPITAL LETTER ALPHA WITH V.. */
 /*2384*/    0x1f71,  1,   0x1fbb, /* GREEK CAPITAL LETTER ALPHA WITH O.. */
 /*2387*/    0x1f72,  1,   0x1fc8, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2390*/    0x1f73,  1,   0x1fc9, /* GREEK CAPITAL LETTER EPSILON WITH.. */
 /*2393*/    0x1f74,  1,   0x1fca, /* GREEK CAPITAL LETTER ETA WITH VAR.. */
 /*2396*/    0x1f75,  1,   0x1fcb, /* GREEK CAPITAL LETTER ETA WITH OXIA */
 /*2399*/    0x1f76,  1,   0x1fda, /* GREEK CAPITAL LETTER IOTA WITH VA.. */
 /*2402*/    0x1f77,  1,   0x1fdb, /* GREEK CAPITAL LETTER IOTA WITH OX.. */
 /*2405*/    0x1f78,  1,   0x1ff8, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2408*/    0x1f79,  1,   0x1ff9, /* GREEK CAPITAL LETTER OMICRON WITH.. */
 /*2411*/    0x1f7a,  1,   0x1fea, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2414*/    0x1f7b,  1,   0x1feb, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2417*/    0x1f7c,  1,   0x1ffa, /* GREEK CAPITAL LETTER OMEGA WITH V.. */
 /*2420*/    0x1f7d,  1,   0x1ffb, /* GREEK CAPITAL LETTER OMEGA WITH O.. */
 /*2423*/    0x1fb0,  1,   0x1fb8, /* GREEK CAPITAL LETTER ALPHA WITH V.. */
 /*2426*/    0x1fb1,  1,   0x1fb9, /* GREEK CAPITAL LETTER ALPHA WITH M.. */
 /*2429*/    0x1fd0,  1,   0x1fd8, /* GREEK CAPITAL LETTER IOTA WITH VR.. */
 /*2432*/    0x1fd1,  1,   0x1fd9, /* GREEK CAPITAL LETTER IOTA WITH MA.. */
 /*2435*/    0x1fe0,  1,   0x1fe8, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2438*/    0x1fe1,  1,   0x1fe9, /* GREEK CAPITAL LETTER UPSILON WITH.. */
 /*2441*/    0x1fe5,  1,   0x1fec, /* GREEK CAPITAL LETTER RHO WITH DAS.. */
 /*2444*/    0x214e,  1,   0x2132, /* TURNED CAPITAL F */
 /*2447*/    0x2170,  1,   0x2160, /* ROMAN NUMERAL ONE */
 /*2450*/    0x2171,  1,   0x2161, /* ROMAN NUMERAL TWO */
 /*2453*/    0x2172,  1,   0x2162, /* ROMAN NUMERAL THREE */
 /*2456*/    0x2173,  1,   0x2163, /* ROMAN NUMERAL FOUR */
 /*2459*/    0x2174,  1,   0x2164, /* ROMAN NUMERAL FIVE */
 /*2462*/    0x2175,  1,   0x2165, /* ROMAN NUMERAL SIX */
 /*2465*/    0x2176,  1,   0x2166, /* ROMAN NUMERAL SEVEN */
 /*2468*/    0x2177,  1,   0x2167, /* ROMAN NUMERAL EIGHT */
 /*2471*/    0x2178,  1,   0x2168, /* ROMAN NUMERAL NINE */
 /*2474*/    0x2179,  1,   0x2169, /* ROMAN NUMERAL TEN */
 /*2477*/    0x217a,  1,   0x216a, /* ROMAN NUMERAL ELEVEN */
 /*2480*/    0x217b,  1,   0x216b, /* ROMAN NUMERAL TWELVE */
 /*2483*/    0x217c,  1,   0x216c, /* ROMAN NUMERAL FIFTY */
 /*2486*/    0x217d,  1,   0x216d, /* ROMAN NUMERAL ONE HUNDRED */
 /*2489*/    0x217e,  1,   0x216e, /* ROMAN NUMERAL FIVE HUNDRED */
 /*2492*/    0x217f,  1,   0x216f, /* ROMAN NUMERAL ONE THOUSAND */
 /*2495*/    0x2184,  1,   0x2183, /* ROMAN NUMERAL REVERSED ONE HUNDRED */
 /*2498*/    0x24d0,  1,   0x24b6, /* CIRCLED LATIN CAPITAL LETTER A */
 /*2501*/    0x24d1,  1,   0x24b7, /* CIRCLED LATIN CAPITAL LETTER B */
 /*2504*/    0x24d2,  1,   0x24b8, /* CIRCLED LATIN CAPITAL LETTER C */
 /*2507*/    0x24d3,  1,   0x24b9, /* CIRCLED LATIN CAPITAL LETTER D */
 /*2510*/    0x24d4,  1,   0x24ba, /* CIRCLED LATIN CAPITAL LETTER E */
 /*2513*/    0x24d5,  1,   0x24bb, /* CIRCLED LATIN CAPITAL LETTER F */
 /*2516*/    0x24d6,  1,   0x24bc, /* CIRCLED LATIN CAPITAL LETTER G */
 /*2519*/    0x24d7,  1,   0x24bd, /* CIRCLED LATIN CAPITAL LETTER H */
 /*2522*/    0x24d8,  1,   0x24be, /* CIRCLED LATIN CAPITAL LETTER I */
 /*2525*/    0x24d9,  1,   0x24bf, /* CIRCLED LATIN CAPITAL LETTER J */
 /*2528*/    0x24da,  1,   0x24c0, /* CIRCLED LATIN CAPITAL LETTER K */
 /*2531*/    0x24db,  1,   0x24c1, /* CIRCLED LATIN CAPITAL LETTER L */
 /*2534*/    0x24dc,  1,   0x24c2, /* CIRCLED LATIN CAPITAL LETTER M */
 /*2537*/    0x24dd,  1,   0x24c3, /* CIRCLED LATIN CAPITAL LETTER N */
 /*2540*/    0x24de,  1,   0x24c4, /* CIRCLED LATIN CAPITAL LETTER O */
 /*2543*/    0x24df,  1,   0x24c5, /* CIRCLED LATIN CAPITAL LETTER P */
 /*2546*/    0x24e0,  1,   0x24c6, /* CIRCLED LATIN CAPITAL LETTER Q */
 /*2549*/    0x24e1,  1,   0x24c7, /* CIRCLED LATIN CAPITAL LETTER R */
 /*2552*/    0x24e2,  1,   0x24c8, /* CIRCLED LATIN CAPITAL LETTER S */
 /*2555*/    0x24e3,  1,   0x24c9, /* CIRCLED LATIN CAPITAL LETTER T */
 /*2558*/    0x24e4,  1,   0x24ca, /* CIRCLED LATIN CAPITAL LETTER U */
 /*2561*/    0x24e5,  1,   0x24cb, /* CIRCLED LATIN CAPITAL LETTER V */
 /*2564*/    0x24e6,  1,   0x24cc, /* CIRCLED LATIN CAPITAL LETTER W */
 /*2567*/    0x24e7,  1,   0x24cd, /* CIRCLED LATIN CAPITAL LETTER X */
 /*2570*/    0x24e8,  1,   0x24ce, /* CIRCLED LATIN CAPITAL LETTER Y */
 /*2573*/    0x24e9,  1,   0x24cf, /* CIRCLED LATIN CAPITAL LETTER Z */
 /*2576*/    0x2c30,  1,   0x2c00, /* GLAGOLITIC CAPITAL LETTER AZU */
 /*2579*/    0x2c31,  1,   0x2c01, /* GLAGOLITIC CAPITAL LETTER BUKY */
 /*2582*/    0x2c32,  1,   0x2c02, /* GLAGOLITIC CAPITAL LETTER VEDE */
 /*2585*/    0x2c33,  1,   0x2c03, /* GLAGOLITIC CAPITAL LETTER GLAGOLI */
 /*2588*/    0x2c34,  1,   0x2c04, /* GLAGOLITIC CAPITAL LETTER DOBRO */
 /*2591*/    0x2c35,  1,   0x2c05, /* GLAGOLITIC CAPITAL LETTER YESTU */
 /*2594*/    0x2c36,  1,   0x2c06, /* GLAGOLITIC CAPITAL LETTER ZHIVETE */
 /*2597*/    0x2c37,  1,   0x2c07, /* GLAGOLITIC CAPITAL LETTER DZELO */
 /*2600*/    0x2c38,  1,   0x2c08, /* GLAGOLITIC CAPITAL LETTER ZEMLJA */
 /*2603*/    0x2c39,  1,   0x2c09, /* GLAGOLITIC CAPITAL LETTER IZHE */
 /*2606*/    0x2c3a,  1,   0x2c0a, /* GLAGOLITIC CAPITAL LETTER INITIAL.. */
 /*2609*/    0x2c3b,  1,   0x2c0b, /* GLAGOLITIC CAPITAL LETTER I */
 /*2612*/    0x2c3c,  1,   0x2c0c, /* GLAGOLITIC CAPITAL LETTER DJERVI */
 /*2615*/    0x2c3d,  1,   0x2c0d, /* GLAGOLITIC CAPITAL LETTER KAKO */
 /*2618*/    0x2c3e,  1,   0x2c0e, /* GLAGOLITIC CAPITAL LETTER LJUDIJE */
 /*2621*/    0x2c3f,  1,   0x2c0f, /* GLAGOLITIC CAPITAL LETTER MYSLITE */
 /*2624*/    0x2c40,  1,   0x2c10, /* GLAGOLITIC CAPITAL LETTER NASHI */
 /*2627*/    0x2c41,  1,   0x2c11, /* GLAGOLITIC CAPITAL LETTER ONU */
 /*2630*/    0x2c42,  1,   0x2c12, /* GLAGOLITIC CAPITAL LETTER POKOJI */
 /*2633*/    0x2c43,  1,   0x2c13, /* GLAGOLITIC CAPITAL LETTER RITSI */
 /*2636*/    0x2c44,  1,   0x2c14, /* GLAGOLITIC CAPITAL LETTER SLOVO */
 /*2639*/    0x2c45,  1,   0x2c15, /* GLAGOLITIC CAPITAL LETTER TVRIDO */
 /*2642*/    0x2c46,  1,   0x2c16, /* GLAGOLITIC CAPITAL LETTER UKU */
 /*2645*/    0x2c47,  1,   0x2c17, /* GLAGOLITIC CAPITAL LETTER FRITU */
 /*2648*/    0x2c48,  1,   0x2c18, /* GLAGOLITIC CAPITAL LETTER HERU */
 /*2651*/    0x2c49,  1,   0x2c19, /* GLAGOLITIC CAPITAL LETTER OTU */
 /*2654*/    0x2c4a,  1,   0x2c1a, /* GLAGOLITIC CAPITAL LETTER PE */
 /*2657*/    0x2c4b,  1,   0x2c1b, /* GLAGOLITIC CAPITAL LETTER SHTA */
 /*2660*/    0x2c4c,  1,   0x2c1c, /* GLAGOLITIC CAPITAL LETTER TSI */
 /*2663*/    0x2c4d,  1,   0x2c1d, /* GLAGOLITIC CAPITAL LETTER CHRIVI */
 /*2666*/    0x2c4e,  1,   0x2c1e, /* GLAGOLITIC CAPITAL LETTER SHA */
 /*2669*/    0x2c4f,  1,   0x2c1f, /* GLAGOLITIC CAPITAL LETTER YERU */
 /*2672*/    0x2c50,  1,   0x2c20, /* GLAGOLITIC CAPITAL LETTER YERI */
 /*2675*/    0x2c51,  1,   0x2c21, /* GLAGOLITIC CAPITAL LETTER YATI */
 /*2678*/    0x2c52,  1,   0x2c22, /* GLAGOLITIC CAPITAL LETTER SPIDERY.. */
 /*2681*/    0x2c53,  1,   0x2c23, /* GLAGOLITIC CAPITAL LETTER YU */
 /*2684*/    0x2c54,  1,   0x2c24, /* GLAGOLITIC CAPITAL LETTER SMALL Y.. */
 /*2687*/    0x2c55,  1,   0x2c25, /* GLAGOLITIC CAPITAL LETTER SMALL Y.. */
 /*2690*/    0x2c56,  1,   0x2c26, /* GLAGOLITIC CAPITAL LETTER YO */
 /*2693*/    0x2c57,  1,   0x2c27, /* GLAGOLITIC CAPITAL LETTER IOTATED.. */
 /*2696*/    0x2c58,  1,   0x2c28, /* GLAGOLITIC CAPITAL LETTER BIG YUS */
 /*2699*/    0x2c59,  1,   0x2c29, /* GLAGOLITIC CAPITAL LETTER IOTATED.. */
 /*2702*/    0x2c5a,  1,   0x2c2a, /* GLAGOLITIC CAPITAL LETTER FITA */
 /*2705*/    0x2c5b,  1,   0x2c2b, /* GLAGOLITIC CAPITAL LETTER IZHITSA */
 /*2708*/    0x2c5c,  1,   0x2c2c, /* GLAGOLITIC CAPITAL LETTER SHTAPIC */
 /*2711*/    0x2c5d,  1,   0x2c2d, /* GLAGOLITIC CAPITAL LETTER TROKUTA.. */
 /*2714*/    0x2c5e,  1,   0x2c2e, /* GLAGOLITIC CAPITAL LETTER LATINAT.. */
 /*2717*/    0x2c5f,  1,   0x2c2f, /* GLAGOLITIC CAPITAL LETTER CAUDATE.. */
 /*2720*/    0x2c61,  1,   0x2c60, /* LATIN CAPITAL LETTER L WITH DOUBL.. */
 /*2723*/    0x2c65,  1,   0x023a, /* LATIN CAPITAL LETTER A WITH STROKE */
 /*2726*/    0x2c66,  1,   0x023e, /* LATIN CAPITAL LETTER T WITH DIAGO.. */
 /*2729*/    0x2c68,  1,   0x2c67, /* LATIN CAPITAL LETTER H WITH DESCE.. */
 /*2732*/    0x2c6a,  1,   0x2c69, /* LATIN CAPITAL LETTER K WITH DESCE.. */
 /*2735*/    0x2c6c,  1,   0x2c6b, /* LATIN CAPITAL LETTER Z WITH DESCE.. */
 /*2738*/    0x2c73,  1,   0x2c72, /* LATIN CAPITAL LETTER W WITH HOOK */
 /*2741*/    0x2c76,  1,   0x2c75, /* LATIN CAPITAL LETTER HALF H */
 /*2744*/    0x2c81,  1,   0x2c80, /* COPTIC CAPITAL LETTER ALFA */
 /*2747*/    0x2c83,  1,   0x2c82, /* COPTIC CAPITAL LETTER VIDA */
 /*2750*/    0x2c85,  1,   0x2c84, /* COPTIC CAPITAL LETTER GAMMA */
 /*2753*/    0x2c87,  1,   0x2c86, /* COPTIC CAPITAL LETTER DALDA */
 /*2756*/    0x2c89,  1,   0x2c88, /* COPTIC CAPITAL LETTER EIE */
 /*2759*/    0x2c8b,  1,   0x2c8a, /* COPTIC CAPITAL LETTER SOU */
 /*2762*/    0x2c8d,  1,   0x2c8c, /* COPTIC CAPITAL LETTER ZATA */
 /*2765*/    0x2c8f,  1,   0x2c8e, /* COPTIC CAPITAL LETTER HATE */
 /*2768*/    0x2c91,  1,   0x2c90, /* COPTIC CAPITAL LETTER THETHE */
 /*2771*/    0x2c93,  1,   0x2c92, /* COPTIC CAPITAL LETTER IAUDA */
 /*2774*/    0x2c95,  1,   0x2c94, /* COPTIC CAPITAL LETTER KAPA */
 /*2777*/    0x2c97,  1,   0x2c96, /* COPTIC CAPITAL LETTER LAULA */
 /*2780*/    0x2c99,  1,   0x2c98, /* COPTIC CAPITAL LETTER MI */
 /*2783*/    0x2c9b,  1,   0x2c9a, /* COPTIC CAPITAL LETTER NI */
 /*2786*/    0x2c9d,  1,   0x2c9c, /* COPTIC CAPITAL LETTER KSI */
 /*2789*/    0x2c9f,  1,   0x2c9e, /* COPTIC CAPITAL LETTER O */
 /*2792*/    0x2ca1,  1,   0x2ca0, /* COPTIC CAPITAL LETTER PI */
 /*2795*/    0x2ca3,  1,   0x2ca2, /* COPTIC CAPITAL LETTER RO */
 /*2798*/    0x2ca5,  1,   0x2ca4, /* COPTIC CAPITAL LETTER SIMA */
 /*2801*/    0x2ca7,  1,   0x2ca6, /* COPTIC CAPITAL LETTER TAU */
 /*2804*/    0x2ca9,  1,   0x2ca8, /* COPTIC CAPITAL LETTER UA */
 /*2807*/    0x2cab,  1,   0x2caa, /* COPTIC CAPITAL LETTER FI */
 /*2810*/    0x2cad,  1,   0x2cac, /* COPTIC CAPITAL LETTER KHI */
 /*2813*/    0x2caf,  1,   0x2cae, /* COPTIC CAPITAL LETTER PSI */
 /*2816*/    0x2cb1,  1,   0x2cb0, /* COPTIC CAPITAL LETTER OOU */
 /*2819*/    0x2cb3,  1,   0x2cb2, /* COPTIC CAPITAL LETTER DIALECT-P A.. */
 /*2822*/    0x2cb5,  1,   0x2cb4, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2825*/    0x2cb7,  1,   0x2cb6, /* COPTIC CAPITAL LETTER CRYPTOGRAMM.. */
 /*2828*/    0x2cb9,  1,   0x2cb8, /* COPTIC CAPITAL LETTER DIALECT-P K.. */
 /*2831*/    0x2cbb,  1,   0x2cba, /* COPTIC CAPITAL LETTER DIALECT-P NI */
 /*2834*/    0x2cbd,  1,   0x2cbc, /* COPTIC CAPITAL LETTER CRYPTOGRAMM.. */
 /*2837*/    0x2cbf,  1,   0x2cbe, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2840*/    0x2cc1,  1,   0x2cc0, /* COPTIC CAPITAL LETTER SAMPI */
 /*2843*/    0x2cc3,  1,   0x2cc2, /* COPTIC CAPITAL LETTER CROSSED SHEI */
 /*2846*/    0x2cc5,  1,   0x2cc4, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2849*/    0x2cc7,  1,   0x2cc6, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2852*/    0x2cc9,  1,   0x2cc8, /* COPTIC CAPITAL LETTER AKHMIMIC KH.. */
 /*2855*/    0x2ccb,  1,   0x2cca, /* COPTIC CAPITAL LETTER DIALECT-P H.. */
 /*2858*/    0x2ccd,  1,   0x2ccc, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2861*/    0x2ccf,  1,   0x2cce, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2864*/    0x2cd1,  1,   0x2cd0, /* COPTIC CAPITAL LETTER L-SHAPED HA */
 /*2867*/    0x2cd3,  1,   0x2cd2, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2870*/    0x2cd5,  1,   0x2cd4, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2873*/    0x2cd7,  1,   0x2cd6, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2876*/    0x2cd9,  1,   0x2cd8, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2879*/    0x2cdb,  1,   0x2cda, /* COPTIC CAPITAL LETTER OLD COPTIC .. */
 /*2882*/    0x2cdd,  1,   0x2cdc, /* COPTIC CAPITAL LETTER OLD NUBIAN .. */
 /*2885*/    0x2cdf,  1,   0x2cde, /* COPTIC CAPITAL LETTER OLD NUBIAN .. */
 /*2888*/    0x2ce1,  1,   0x2ce0, /* COPTIC CAPITAL LETTER OLD NUBIAN .. */
 /*2891*/    0x2ce3,  1,   0x2ce2, /* COPTIC CAPITAL LETTER OLD NUBIAN .. */
 /*2894*/    0x2cec,  1,   0x2ceb, /* COPTIC CAPITAL LETTER CRYPTOGRAMM.. */
 /*2897*/    0x2cee,  1,   0x2ced, /* COPTIC CAPITAL LETTER CRYPTOGRAMM.. */
 /*2900*/    0x2cf3,  1,   0x2cf2, /* COPTIC CAPITAL LETTER BOHAIRIC KH.. */
 /*2903*/    0x2d00,  1,   0x10a0, /* GEORGIAN CAPITAL LETTER AN */
 /*2906*/    0x2d01,  1,   0x10a1, /* GEORGIAN CAPITAL LETTER BAN */
 /*2909*/    0x2d02,  1,   0x10a2, /* GEORGIAN CAPITAL LETTER GAN */
 /*2912*/    0x2d03,  1,   0x10a3, /* GEORGIAN CAPITAL LETTER DON */
 /*2915*/    0x2d04,  1,   0x10a4, /* GEORGIAN CAPITAL LETTER EN */
 /*2918*/    0x2d05,  1,   0x10a5, /* GEORGIAN CAPITAL LETTER VIN */
 /*2921*/    0x2d06,  1,   0x10a6, /* GEORGIAN CAPITAL LETTER ZEN */
 /*2924*/    0x2d07,  1,   0x10a7, /* GEORGIAN CAPITAL LETTER TAN */
 /*2927*/    0x2d08,  1,   0x10a8, /* GEORGIAN CAPITAL LETTER IN */
 /*2930*/    0x2d09,  1,   0x10a9, /* GEORGIAN CAPITAL LETTER KAN */
 /*2933*/    0x2d0a,  1,   0x10aa, /* GEORGIAN CAPITAL LETTER LAS */
 /*2936*/    0x2d0b,  1,   0x10ab, /* GEORGIAN CAPITAL LETTER MAN */
 /*2939*/    0x2d0c,  1,   0x10ac, /* GEORGIAN CAPITAL LETTER NAR */
 /*2942*/    0x2d0d,  1,   0x10ad, /* GEORGIAN CAPITAL LETTER ON */
 /*2945*/    0x2d0e,  1,   0x10ae, /* GEORGIAN CAPITAL LETTER PAR */
 /*2948*/    0x2d0f,  1,   0x10af, /* GEORGIAN CAPITAL LETTER ZHAR */
 /*2951*/    0x2d10,  1,   0x10b0, /* GEORGIAN CAPITAL LETTER RAE */
 /*2954*/    0x2d11,  1,   0x10b1, /* GEORGIAN CAPITAL LETTER SAN */
 /*2957*/    0x2d12,  1,   0x10b2, /* GEORGIAN CAPITAL LETTER TAR */
 /*2960*/    0x2d13,  1,   0x10b3, /* GEORGIAN CAPITAL LETTER UN */
 /*2963*/    0x2d14,  1,   0x10b4, /* GEORGIAN CAPITAL LETTER PHAR */
 /*2966*/    0x2d15,  1,   0x10b5, /* GEORGIAN CAPITAL LETTER KHAR */
 /*2969*/    0x2d16,  1,   0x10b6, /* GEORGIAN CAPITAL LETTER GHAN */
 /*2972*/    0x2d17,  1,   0x10b7, /* GEORGIAN CAPITAL LETTER QAR */
 /*2975*/    0x2d18,  1,   0x10b8, /* GEORGIAN CAPITAL LETTER SHIN */
 /*2978*/    0x2d19,  1,   0x10b9, /* GEORGIAN CAPITAL LETTER CHIN */
 /*2981*/    0x2d1a,  1,   0x10ba, /* GEORGIAN CAPITAL LETTER CAN */
 /*2984*/    0x2d1b,  1,   0x10bb, /* GEORGIAN CAPITAL LETTER JIL */
 /*2987*/    0x2d1c,  1,   0x10bc, /* GEORGIAN CAPITAL LETTER CIL */
 /*2990*/    0x2d1d,  1,   0x10bd, /* GEORGIAN CAPITAL LETTER CHAR */
 /*2993*/    0x2d1e,  1,   0x10be, /* GEORGIAN CAPITAL LETTER XAN */
 /*2996*/    0x2d1f,  1,   0x10bf, /* GEORGIAN CAPITAL LETTER JHAN */
 /*2999*/    0x2d20,  1,   0x10c0, /* GEORGIAN CAPITAL LETTER HAE */
 /*3002*/    0x2d21,  1,   0x10c1, /* GEORGIAN CAPITAL LETTER HE */
 /*3005*/    0x2d22,  1,   0x10c2, /* GEORGIAN CAPITAL LETTER HIE */
 /*3008*/    0x2d23,  1,   0x10c3, /* GEORGIAN CAPITAL LETTER WE */
 /*3011*/    0x2d24,  1,   0x10c4, /* GEORGIAN CAPITAL LETTER HAR */
 /*3014*/    0x2d25,  1,   0x10c5, /* GEORGIAN CAPITAL LETTER HOE */
 /*3017*/    0x2d27,  1,   0x10c7, /* GEORGIAN CAPITAL LETTER YN */
 /*3020*/    0x2d2d,  1,   0x10cd, /* GEORGIAN CAPITAL LETTER AEN */
 /*3023*/    0xa641,  1,   0xa640, /* CYRILLIC CAPITAL LETTER ZEMLYA */
 /*3026*/    0xa643,  1,   0xa642, /* CYRILLIC CAPITAL LETTER DZELO */
 /*3029*/    0xa645,  1,   0xa644, /* CYRILLIC CAPITAL LETTER REVERSED .. */
 /*3032*/    0xa647,  1,   0xa646, /* CYRILLIC CAPITAL LETTER IOTA */
 /*3035*/    0xa649,  1,   0xa648, /* CYRILLIC CAPITAL LETTER DJERV */
 /*3038*/    0xa64b,  2,   0x1c88,   0xa64a, /* CYRILLIC SMALL LETTER UNBLENDED UK */
 /*3042*/    0xa64d,  1,   0xa64c, /* CYRILLIC CAPITAL LETTER BROAD OME.. */
 /*3045*/    0xa64f,  1,   0xa64e, /* CYRILLIC CAPITAL LETTER NEUTRAL Y.. */
 /*3048*/    0xa651,  1,   0xa650, /* CYRILLIC CAPITAL LETTER YERU WITH.. */
 /*3051*/    0xa653,  1,   0xa652, /* CYRILLIC CAPITAL LETTER IOTIFIED .. */
 /*3054*/    0xa655,  1,   0xa654, /* CYRILLIC CAPITAL LETTER REVERSED .. */
 /*3057*/    0xa657,  1,   0xa656, /* CYRILLIC CAPITAL LETTER IOTIFIED A */
 /*3060*/    0xa659,  1,   0xa658, /* CYRILLIC CAPITAL LETTER CLOSED LI.. */
 /*3063*/    0xa65b,  1,   0xa65a, /* CYRILLIC CAPITAL LETTER BLENDED Y.. */
 /*3066*/    0xa65d,  1,   0xa65c, /* CYRILLIC CAPITAL LETTER IOTIFIED .. */
 /*3069*/    0xa65f,  1,   0xa65e, /* CYRILLIC CAPITAL LETTER YN */
 /*3072*/    0xa661,  1,   0xa660, /* CYRILLIC CAPITAL LETTER REVERSED .. */
 /*3075*/    0xa663,  1,   0xa662, /* CYRILLIC CAPITAL LETTER SOFT DE */
 /*3078*/    0xa665,  1,   0xa664, /* CYRILLIC CAPITAL LETTER SOFT EL */
 /*3081*/    0xa667,  1,   0xa666, /* CYRILLIC CAPITAL LETTER SOFT EM */
 /*3084*/    0xa669,  1,   0xa668, /* CYRILLIC CAPITAL LETTER MONOCULAR.. */
 /*3087*/    0xa66b,  1,   0xa66a, /* CYRILLIC CAPITAL LETTER BINOCULAR.. */
 /*3090*/    0xa66d,  1,   0xa66c, /* CYRILLIC CAPITAL LETTER DOUBLE MO.. */
 /*3093*/    0xa681,  1,   0xa680, /* CYRILLIC CAPITAL LETTER DWE */
 /*3096*/    0xa683,  1,   0xa682, /* CYRILLIC CAPITAL LETTER DZWE */
 /*3099*/    0xa685,  1,   0xa684, /* CYRILLIC CAPITAL LETTER ZHWE */
 /*3102*/    0xa687,  1,   0xa686, /* CYRILLIC CAPITAL LETTER CCHE */
 /*3105*/    0xa689,  1,   0xa688, /* CYRILLIC CAPITAL LETTER DZZE */
 /*3108*/    0xa68b,  1,   0xa68a, /* CYRILLIC CAPITAL LETTER TE WITH M.. */
 /*3111*/    0xa68d,  1,   0xa68c, /* CYRILLIC CAPITAL LETTER TWE */
 /*3114*/    0xa68f,  1,   0xa68e, /* CYRILLIC CAPITAL LETTER TSWE */
 /*3117*/    0xa691,  1,   0xa690, /* CYRILLIC CAPITAL LETTER TSSE */
 /*3120*/    0xa693,  1,   0xa692, /* CYRILLIC CAPITAL LETTER TCHE */
 /*3123*/    0xa695,  1,   0xa694, /* CYRILLIC CAPITAL LETTER HWE */
 /*3126*/    0xa697,  1,   0xa696, /* CYRILLIC CAPITAL LETTER SHWE */
 /*3129*/    0xa699,  1,   0xa698, /* CYRILLIC CAPITAL LETTER DOUBLE O */
 /*3132*/    0xa69b,  1,   0xa69a, /* CYRILLIC CAPITAL LETTER CROSSED O */
 /*3135*/    0xa723,  1,   0xa722, /* LATIN CAPITAL LETTER EGYPTOLOGICA.. */
 /*3138*/    0xa725,  1,   0xa724, /* LATIN CAPITAL LETTER EGYPTOLOGICA.. */
 /*3141*/    0xa727,  1,   0xa726, /* LATIN CAPITAL LETTER HENG */
 /*3144*/    0xa729,  1,   0xa728, /* LATIN CAPITAL LETTER TZ */
 /*3147*/    0xa72b,  1,   0xa72a, /* LATIN CAPITAL LETTER TRESILLO */
 /*3150*/    0xa72d,  1,   0xa72c, /* LATIN CAPITAL LETTER CUATRILLO */
 /*3153*/    0xa72f,  1,   0xa72e, /* LATIN CAPITAL LETTER CUATRILLO WI.. */
 /*3156*/    0xa733,  1,   0xa732, /* LATIN CAPITAL LETTER AA */
 /*3159*/    0xa735,  1,   0xa734, /* LATIN CAPITAL LETTER AO */
 /*3162*/    0xa737,  1,   0xa736, /* LATIN CAPITAL LETTER AU */
 /*3165*/    0xa739,  1,   0xa738, /* LATIN CAPITAL LETTER AV */
 /*3168*/    0xa73b,  1,   0xa73a, /* LATIN CAPITAL LETTER AV WITH HORI.. */
 /*3171*/    0xa73d,  1,   0xa73c, /* LATIN CAPITAL LETTER AY */
 /*3174*/    0xa73f,  1,   0xa73e, /* LATIN CAPITAL LETTER REVERSED C W.. */
 /*3177*/    0xa741,  1,   0xa740, /* LATIN CAPITAL LETTER K WITH STROKE */
 /*3180*/    0xa743,  1,   0xa742, /* LATIN CAPITAL LETTER K WITH DIAGO.. */
 /*3183*/    0xa745,  1,   0xa744, /* LATIN CAPITAL LETTER K WITH STROK.. */
 /*3186*/    0xa747,  1,   0xa746, /* LATIN CAPITAL LETTER BROKEN L */
 /*3189*/    0xa749,  1,   0xa748, /* LATIN CAPITAL LETTER L WITH HIGH .. */
 /*3192*/    0xa74b,  1,   0xa74a, /* LATIN CAPITAL LETTER O WITH LONG .. */
 /*3195*/    0xa74d,  1,   0xa74c, /* LATIN CAPITAL LETTER O WITH LOOP */
 /*3198*/    0xa74f,  1,   0xa74e, /* LATIN CAPITAL LETTER OO */
 /*3201*/    0xa751,  1,   0xa750, /* LATIN CAPITAL LETTER P WITH STROK.. */
 /*3204*/    0xa753,  1,   0xa752, /* LATIN CAPITAL LETTER P WITH FLOUR.. */
 /*3207*/    0xa755,  1,   0xa754, /* LATIN CAPITAL LETTER P WITH SQUIR.. */
 /*3210*/    0xa757,  1,   0xa756, /* LATIN CAPITAL LETTER Q WITH STROK.. */
 /*3213*/    0xa759,  1,   0xa758, /* LATIN CAPITAL LETTER Q WITH DIAGO.. */
 /*3216*/    0xa75b,  1,   0xa75a, /* LATIN CAPITAL LETTER R ROTUNDA */
 /*3219*/    0xa75d,  1,   0xa75c, /* LATIN CAPITAL LETTER RUM ROTUNDA */
 /*3222*/    0xa75f,  1,   0xa75e, /* LATIN CAPITAL LETTER V WITH DIAGO.. */
 /*3225*/    0xa761,  1,   0xa760, /* LATIN CAPITAL LETTER VY */
 /*3228*/    0xa763,  1,   0xa762, /* LATIN CAPITAL LETTER VISIGOTHIC Z */
 /*3231*/    0xa765,  1,   0xa764, /* LATIN CAPITAL LETTER THORN WITH S.. */
 /*3234*/    0xa767,  1,   0xa766, /* LATIN CAPITAL LETTER THORN WITH S.. */
 /*3237*/    0xa769,  1,   0xa768, /* LATIN CAPITAL LETTER VEND */
 /*3240*/    0xa76b,  1,   0xa76a, /* LATIN CAPITAL LETTER ET */
 /*3243*/    0xa76d,  1,   0xa76c, /* LATIN CAPITAL LETTER IS */
 /*3246*/    0xa76f,  1,   0xa76e, /* LATIN CAPITAL LETTER CON */
 /*3249*/    0xa77a,  1,   0xa779, /* LATIN CAPITAL LETTER INSULAR D */
 /*3252*/    0xa77c,  1,   0xa77b, /* LATIN CAPITAL LETTER INSULAR F */
 /*3255*/    0xa77f,  1,   0xa77e, /* LATIN CAPITAL LETTER TURNED INSUL.. */
 /*3258*/    0xa781,  1,   0xa780, /* LATIN CAPITAL LETTER TURNED L */
 /*3261*/    0xa783,  1,   0xa782, /* LATIN CAPITAL LETTER INSULAR R */
 /*3264*/    0xa785,  1,   0xa784, /* LATIN CAPITAL LETTER INSULAR S */
 /*3267*/    0xa787,  1,   0xa786, /* LATIN CAPITAL LETTER INSULAR T */
 /*3270*/    0xa78c,  1,   0xa78b, /* LATIN CAPITAL LETTER SALTILLO */
 /*3273*/    0xa791,  1,   0xa790, /* LATIN CAPITAL LETTER N WITH DESCE.. */
 /*3276*/    0xa793,  1,   0xa792, /* LATIN CAPITAL LETTER C WITH BAR */
 /*3279*/    0xa794,  1,   0xa7c4, /* LATIN CAPITAL LETTER C WITH PALAT.. */
 /*3282*/    0xa797,  1,   0xa796, /* LATIN CAPITAL LETTER B WITH FLOUR.. */
 /*3285*/    0xa799,  1,   0xa798, /* LATIN CAPITAL LETTER F WITH STROKE */
 /*3288*/    0xa79b,  1,   0xa79a, /* LATIN CAPITAL LETTER VOLAPUK AE */
 /*3291*/    0xa79d,  1,   0xa79c, /* LATIN CAPITAL LETTER VOLAPUK OE */
 /*3294*/    0xa79f,  1,   0xa79e, /* LATIN CAPITAL LETTER VOLAPUK UE */
 /*3297*/    0xa7a1,  1,   0xa7a0, /* LATIN CAPITAL LETTER G WITH OBLIQ.. */
 /*3300*/    0xa7a3,  1,   0xa7a2, /* LATIN CAPITAL LETTER K WITH OBLIQ.. */
 /*3303*/    0xa7a5,  1,   0xa7a4, /* LATIN CAPITAL LETTER N WITH OBLIQ.. */
 /*3306*/    0xa7a7,  1,   0xa7a6, /* LATIN CAPITAL LETTER R WITH OBLIQ.. */
 /*3309*/    0xa7a9,  1,   0xa7a8, /* LATIN CAPITAL LETTER S WITH OBLIQ.. */
 /*3312*/    0xa7b5,  1,   0xa7b4, /* LATIN CAPITAL LETTER BETA */
 /*3315*/    0xa7b7,  1,   0xa7b6, /* LATIN CAPITAL LETTER OMEGA */
 /*3318*/    0xa7b9,  1,   0xa7b8, /* LATIN CAPITAL LETTER U WITH STROKE */
 /*3321*/    0xa7bb,  1,   0xa7ba, /* LATIN CAPITAL LETTER GLOTTAL A */
 /*3324*/    0xa7bd,  1,   0xa7bc, /* LATIN CAPITAL LETTER GLOTTAL I */
 /*3327*/    0xa7bf,  1,   0xa7be, /* LATIN CAPITAL LETTER GLOTTAL U */
 /*3330*/    0xa7c1,  1,   0xa7c0, /* LATIN CAPITAL LETTER OLD POLISH O */
 /*3333*/    0xa7c3,  1,   0xa7c2, /* LATIN CAPITAL LETTER ANGLICANA W */
 /*3336*/    0xa7c8,  1,   0xa7c7, /* LATIN CAPITAL LETTER D WITH SHORT.. */
 /*3339*/    0xa7ca,  1,   0xa7c9, /* LATIN CAPITAL LETTER S WITH SHORT.. */
 /*3342*/    0xa7d1,  1,   0xa7d0, /* LATIN CAPITAL LETTER CLOSED INSUL.. */
 /*3345*/    0xa7d7,  1,   0xa7d6, /* LATIN CAPITAL LETTER MIDDLE SCOTS.. */
 /*3348*/    0xa7d9,  1,   0xa7d8, /* LATIN CAPITAL LETTER SIGMOID S */
 /*3351*/    0xa7f6,  1,   0xa7f5, /* LATIN CAPITAL LETTER REVERSED HAL.. */
 /*3354*/    0xab53,  1,   0xa7b3, /* LATIN CAPITAL LETTER CHI */
 /*3357*/    0xff41,  1,   0xff21, /* FULLWIDTH LATIN CAPITAL LETTER A */
 /*3360*/    0xff42,  1,   0xff22, /* FULLWIDTH LATIN CAPITAL LETTER B */
 /*3363*/    0xff43,  1,   0xff23, /* FULLWIDTH LATIN CAPITAL LETTER C */
 /*3366*/    0xff44,  1,   0xff24, /* FULLWIDTH LATIN CAPITAL LETTER D */
 /*3369*/    0xff45,  1,   0xff25, /* FULLWIDTH LATIN CAPITAL LETTER E */
 /*3372*/    0xff46,  1,   0xff26, /* FULLWIDTH LATIN CAPITAL LETTER F */
 /*3375*/    0xff47,  1,   0xff27, /* FULLWIDTH LATIN CAPITAL LETTER G */
 /*3378*/    0xff48,  1,   0xff28, /* FULLWIDTH LATIN CAPITAL LETTER H */
 /*3381*/    0xff49,  1,   0xff29, /* FULLWIDTH LATIN CAPITAL LETTER I */
 /*3384*/    0xff4a,  1,   0xff2a, /* FULLWIDTH LATIN CAPITAL LETTER J */
 /*3387*/    0xff4b,  1,   0xff2b, /* FULLWIDTH LATIN CAPITAL LETTER K */
 /*3390*/    0xff4c,  1,   0xff2c, /* FULLWIDTH LATIN CAPITAL LETTER L */
 /*3393*/    0xff4d,  1,   0xff2d, /* FULLWIDTH LATIN CAPITAL LETTER M */
 /*3396*/    0xff4e,  1,   0xff2e, /* FULLWIDTH LATIN CAPITAL LETTER N */
 /*3399*/    0xff4f,  1,   0xff2f, /* FULLWIDTH LATIN CAPITAL LETTER O */
 /*3402*/    0xff50,  1,   0xff30, /* FULLWIDTH LATIN CAPITAL LETTER P */
 /*3405*/    0xff51,  1,   0xff31, /* FULLWIDTH LATIN CAPITAL LETTER Q */
 /*3408*/    0xff52,  1,   0xff32, /* FULLWIDTH LATIN CAPITAL LETTER R */
 /*3411*/    0xff53,  1,   0xff33, /* FULLWIDTH LATIN CAPITAL LETTER S */
 /*3414*/    0xff54,  1,   0xff34, /* FULLWIDTH LATIN CAPITAL LETTER T */
 /*3417*/    0xff55,  1,   0xff35, /* FULLWIDTH LATIN CAPITAL LETTER U */
 /*3420*/    0xff56,  1,   0xff36, /* FULLWIDTH LATIN CAPITAL LETTER V */
 /*3423*/    0xff57,  1,   0xff37, /* FULLWIDTH LATIN CAPITAL LETTER W */
 /*3426*/    0xff58,  1,   0xff38, /* FULLWIDTH LATIN CAPITAL LETTER X */
 /*3429*/    0xff59,  1,   0xff39, /* FULLWIDTH LATIN CAPITAL LETTER Y */
 /*3432*/    0xff5a,  1,   0xff3a, /* FULLWIDTH LATIN CAPITAL LETTER Z */
 /*3435*/  0x010428,  1, 0x010400, /* DESERET CAPITAL LETTER LONG I */
 /*3438*/  0x010429,  1, 0x010401, /* DESERET CAPITAL LETTER LONG E */
 /*3441*/  0x01042a,  1, 0x010402, /* DESERET CAPITAL LETTER LONG A */
 /*3444*/  0x01042b,  1, 0x010403, /* DESERET CAPITAL LETTER LONG AH */
 /*3447*/  0x01042c,  1, 0x010404, /* DESERET CAPITAL LETTER LONG O */
 /*3450*/  0x01042d,  1, 0x010405, /* DESERET CAPITAL LETTER LONG OO */
 /*3453*/  0x01042e,  1, 0x010406, /* DESERET CAPITAL LETTER SHORT I */
 /*3456*/  0x01042f,  1, 0x010407, /* DESERET CAPITAL LETTER SHORT E */
 /*3459*/  0x010430,  1, 0x010408, /* DESERET CAPITAL LETTER SHORT A */
 /*3462*/  0x010431,  1, 0x010409, /* DESERET CAPITAL LETTER SHORT AH */
 /*3465*/  0x010432,  1, 0x01040a, /* DESERET CAPITAL LETTER SHORT O */
 /*3468*/  0x010433,  1, 0x01040b, /* DESERET CAPITAL LETTER SHORT OO */
 /*3471*/  0x010434,  1, 0x01040c, /* DESERET CAPITAL LETTER AY */
 /*3474*/  0x010435,  1, 0x01040d, /* DESERET CAPITAL LETTER OW */
 /*3477*/  0x010436,  1, 0x01040e, /* DESERET CAPITAL LETTER WU */
 /*3480*/  0x010437,  1, 0x01040f, /* DESERET CAPITAL LETTER YEE */
 /*3483*/  0x010438,  1, 0x010410, /* DESERET CAPITAL LETTER H */
 /*3486*/  0x010439,  1, 0x010411, /* DESERET CAPITAL LETTER PEE */
 /*3489*/  0x01043a,  1, 0x010412, /* DESERET CAPITAL LETTER BEE */
 /*3492*/  0x01043b,  1, 0x010413, /* DESERET CAPITAL LETTER TEE */
 /*3495*/  0x01043c,  1, 0x010414, /* DESERET CAPITAL LETTER DEE */
 /*3498*/  0x01043d,  1, 0x010415, /* DESERET CAPITAL LETTER CHEE */
 /*3501*/  0x01043e,  1, 0x010416, /* DESERET CAPITAL LETTER JEE */
 /*3504*/  0x01043f,  1, 0x010417, /* DESERET CAPITAL LETTER KAY */
 /*3507*/  0x010440,  1, 0x010418, /* DESERET CAPITAL LETTER GAY */
 /*3510*/  0x010441,  1, 0x010419, /* DESERET CAPITAL LETTER EF */
 /*3513*/  0x010442,  1, 0x01041a, /* DESERET CAPITAL LETTER VEE */
 /*3516*/  0x010443,  1, 0x01041b, /* DESERET CAPITAL LETTER ETH */
 /*3519*/  0x010444,  1, 0x01041c, /* DESERET CAPITAL LETTER THEE */
 /*3522*/  0x010445,  1, 0x01041d, /* DESERET CAPITAL LETTER ES */
 /*3525*/  0x010446,  1, 0x01041e, /* DESERET CAPITAL LETTER ZEE */
 /*3528*/  0x010447,  1, 0x01041f, /* DESERET CAPITAL LETTER ESH */
 /*3531*/  0x010448,  1, 0x010420, /* DESERET CAPITAL LETTER ZHEE */
 /*3534*/  0x010449,  1, 0x010421, /* DESERET CAPITAL LETTER ER */
 /*3537*/  0x01044a,  1, 0x010422, /* DESERET CAPITAL LETTER EL */
 /*3540*/  0x01044b,  1, 0x010423, /* DESERET CAPITAL LETTER EM */
 /*3543*/  0x01044c,  1, 0x010424, /* DESERET CAPITAL LETTER EN */
 /*3546*/  0x01044d,  1, 0x010425, /* DESERET CAPITAL LETTER ENG */
 /*3549*/  0x01044e,  1, 0x010426, /* DESERET CAPITAL LETTER OI */
 /*3552*/  0x01044f,  1, 0x010427, /* DESERET CAPITAL LETTER EW */
 /*3555*/  0x0104d8,  1, 0x0104b0, /* OSAGE CAPITAL LETTER A */
 /*3558*/  0x0104d9,  1, 0x0104b1, /* OSAGE CAPITAL LETTER AI */
 /*3561*/  0x0104da,  1, 0x0104b2, /* OSAGE CAPITAL LETTER AIN */
 /*3564*/  0x0104db,  1, 0x0104b3, /* OSAGE CAPITAL LETTER AH */
 /*3567*/  0x0104dc,  1, 0x0104b4, /* OSAGE CAPITAL LETTER BRA */
 /*3570*/  0x0104dd,  1, 0x0104b5, /* OSAGE CAPITAL LETTER CHA */
 /*3573*/  0x0104de,  1, 0x0104b6, /* OSAGE CAPITAL LETTER EHCHA */
 /*3576*/  0x0104df,  1, 0x0104b7, /* OSAGE CAPITAL LETTER E */
 /*3579*/  0x0104e0,  1, 0x0104b8, /* OSAGE CAPITAL LETTER EIN */
 /*3582*/  0x0104e1,  1, 0x0104b9, /* OSAGE CAPITAL LETTER HA */
 /*3585*/  0x0104e2,  1, 0x0104ba, /* OSAGE CAPITAL LETTER HYA */
 /*3588*/  0x0104e3,  1, 0x0104bb, /* OSAGE CAPITAL LETTER I */
 /*3591*/  0x0104e4,  1, 0x0104bc, /* OSAGE CAPITAL LETTER KA */
 /*3594*/  0x0104e5,  1, 0x0104bd, /* OSAGE CAPITAL LETTER EHKA */
 /*3597*/  0x0104e6,  1, 0x0104be, /* OSAGE CAPITAL LETTER KYA */
 /*3600*/  0x0104e7,  1, 0x0104bf, /* OSAGE CAPITAL LETTER LA */
 /*3603*/  0x0104e8,  1, 0x0104c0, /* OSAGE CAPITAL LETTER MA */
 /*3606*/  0x0104e9,  1, 0x0104c1, /* OSAGE CAPITAL LETTER NA */
 /*3609*/  0x0104ea,  1, 0x0104c2, /* OSAGE CAPITAL LETTER O */
 /*3612*/  0x0104eb,  1, 0x0104c3, /* OSAGE CAPITAL LETTER OIN */
 /*3615*/  0x0104ec,  1, 0x0104c4, /* OSAGE CAPITAL LETTER PA */
 /*3618*/  0x0104ed,  1, 0x0104c5, /* OSAGE CAPITAL LETTER EHPA */
 /*3621*/  0x0104ee,  1, 0x0104c6, /* OSAGE CAPITAL LETTER SA */
 /*3624*/  0x0104ef,  1, 0x0104c7, /* OSAGE CAPITAL LETTER SHA */
 /*3627*/  0x0104f0,  1, 0x0104c8, /* OSAGE CAPITAL LETTER TA */
 /*3630*/  0x0104f1,  1, 0x0104c9, /* OSAGE CAPITAL LETTER EHTA */
 /*3633*/  0x0104f2,  1, 0x0104ca, /* OSAGE CAPITAL LETTER TSA */
 /*3636*/  0x0104f3,  1, 0x0104cb, /* OSAGE CAPITAL LETTER EHTSA */
 /*3639*/  0x0104f4,  1, 0x0104cc, /* OSAGE CAPITAL LETTER TSHA */
 /*3642*/  0x0104f5,  1, 0x0104cd, /* OSAGE CAPITAL LETTER DHA */
 /*3645*/  0x0104f6,  1, 0x0104ce, /* OSAGE CAPITAL LETTER U */
 /*3648*/  0x0104f7,  1, 0x0104cf, /* OSAGE CAPITAL LETTER WA */
 /*3651*/  0x0104f8,  1, 0x0104d0, /* OSAGE CAPITAL LETTER KHA */
 /*3654*/  0x0104f9,  1, 0x0104d1, /* OSAGE CAPITAL LETTER GHA */
 /*3657*/  0x0104fa,  1, 0x0104d2, /* OSAGE CAPITAL LETTER ZA */
 /*3660*/  0x0104fb,  1, 0x0104d3, /* OSAGE CAPITAL LETTER ZHA */
 /*3663*/  0x010597,  1, 0x010570, /* VITHKUQI CAPITAL LETTER A */
 /*3666*/  0x010598,  1, 0x010571, /* VITHKUQI CAPITAL LETTER BBE */
 /*3669*/  0x010599,  1, 0x010572, /* VITHKUQI CAPITAL LETTER BE */
 /*3672*/  0x01059a,  1, 0x010573, /* VITHKUQI CAPITAL LETTER CE */
 /*3675*/  0x01059b,  1, 0x010574, /* VITHKUQI CAPITAL LETTER CHE */
 /*3678*/  0x01059c,  1, 0x010575, /* VITHKUQI CAPITAL LETTER DE */
 /*3681*/  0x01059d,  1, 0x010576, /* VITHKUQI CAPITAL LETTER DHE */
 /*3684*/  0x01059e,  1, 0x010577, /* VITHKUQI CAPITAL LETTER EI */
 /*3687*/  0x01059f,  1, 0x010578, /* VITHKUQI CAPITAL LETTER E */
 /*3690*/  0x0105a0,  1, 0x010579, /* VITHKUQI CAPITAL LETTER FE */
 /*3693*/  0x0105a1,  1, 0x01057a, /* VITHKUQI CAPITAL LETTER GA */
 /*3696*/  0x0105a3,  1, 0x01057c, /* VITHKUQI CAPITAL LETTER HA */
 /*3699*/  0x0105a4,  1, 0x01057d, /* VITHKUQI CAPITAL LETTER HHA */
 /*3702*/  0x0105a5,  1, 0x01057e, /* VITHKUQI CAPITAL LETTER I */
 /*3705*/  0x0105a6,  1, 0x01057f, /* VITHKUQI CAPITAL LETTER IJE */
 /*3708*/  0x0105a7,  1, 0x010580, /* VITHKUQI CAPITAL LETTER JE */
 /*3711*/  0x0105a8,  1, 0x010581, /* VITHKUQI CAPITAL LETTER KA */
 /*3714*/  0x0105a9,  1, 0x010582, /* VITHKUQI CAPITAL LETTER LA */
 /*3717*/  0x0105aa,  1, 0x010583, /* VITHKUQI CAPITAL LETTER LLA */
 /*3720*/  0x0105ab,  1, 0x010584, /* VITHKUQI CAPITAL LETTER ME */
 /*3723*/  0x0105ac,  1, 0x010585, /* VITHKUQI CAPITAL LETTER NE */
 /*3726*/  0x0105ad,  1, 0x010586, /* VITHKUQI CAPITAL LETTER NJE */
 /*3729*/  0x0105ae,  1, 0x010587, /* VITHKUQI CAPITAL LETTER O */
 /*3732*/  0x0105af,  1, 0x010588, /* VITHKUQI CAPITAL LETTER PE */
 /*3735*/  0x0105b0,  1, 0x010589, /* VITHKUQI CAPITAL LETTER QA */
 /*3738*/  0x0105b1,  1, 0x01058a, /* VITHKUQI CAPITAL LETTER RE */
 /*3741*/  0x0105b3,  1, 0x01058c, /* VITHKUQI CAPITAL LETTER SE */
 /*3744*/  0x0105b4,  1, 0x01058d, /* VITHKUQI CAPITAL LETTER SHE */
 /*3747*/  0x0105b5,  1, 0x01058e, /* VITHKUQI CAPITAL LETTER TE */
 /*3750*/  0x0105b6,  1, 0x01058f, /* VITHKUQI CAPITAL LETTER THE */
 /*3753*/  0x0105b7,  1, 0x010590, /* VITHKUQI CAPITAL LETTER U */
 /*3756*/  0x0105b8,  1, 0x010591, /* VITHKUQI CAPITAL LETTER VE */
 /*3759*/  0x0105b9,  1, 0x010592, /* VITHKUQI CAPITAL LETTER XE */
 /*3762*/  0x0105bb,  1, 0x010594, /* VITHKUQI CAPITAL LETTER Y */
 /*3765*/  0x0105bc,  1, 0x010595, /* VITHKUQI CAPITAL LETTER ZE */
 /*3768*/  0x010cc0,  1, 0x010c80, /* OLD HUNGARIAN CAPITAL LETTER A */
 /*3771*/  0x010cc1,  1, 0x010c81, /* OLD HUNGARIAN CAPITAL LETTER AA */
 /*3774*/  0x010cc2,  1, 0x010c82, /* OLD HUNGARIAN CAPITAL LETTER EB */
 /*3777*/  0x010cc3,  1, 0x010c83, /* OLD HUNGARIAN CAPITAL LETTER AMB */
 /*3780*/  0x010cc4,  1, 0x010c84, /* OLD HUNGARIAN CAPITAL LETTER EC */
 /*3783*/  0x010cc5,  1, 0x010c85, /* OLD HUNGARIAN CAPITAL LETTER ENC */
 /*3786*/  0x010cc6,  1, 0x010c86, /* OLD HUNGARIAN CAPITAL LETTER ECS */
 /*3789*/  0x010cc7,  1, 0x010c87, /* OLD HUNGARIAN CAPITAL LETTER ED */
 /*3792*/  0x010cc8,  1, 0x010c88, /* OLD HUNGARIAN CAPITAL LETTER AND */
 /*3795*/  0x010cc9,  1, 0x010c89, /* OLD HUNGARIAN CAPITAL LETTER E */
 /*3798*/  0x010cca,  1, 0x010c8a, /* OLD HUNGARIAN CAPITAL LETTER CLOS.. */
 /*3801*/  0x010ccb,  1, 0x010c8b, /* OLD HUNGARIAN CAPITAL LETTER EE */
 /*3804*/  0x010ccc,  1, 0x010c8c, /* OLD HUNGARIAN CAPITAL LETTER EF */
 /*3807*/  0x010ccd,  1, 0x010c8d, /* OLD HUNGARIAN CAPITAL LETTER EG */
 /*3810*/  0x010cce,  1, 0x010c8e, /* OLD HUNGARIAN CAPITAL LETTER EGY */
 /*3813*/  0x010ccf,  1, 0x010c8f, /* OLD HUNGARIAN CAPITAL LETTER EH */
 /*3816*/  0x010cd0,  1, 0x010c90, /* OLD HUNGARIAN CAPITAL LETTER I */
 /*3819*/  0x010cd1,  1, 0x010c91, /* OLD HUNGARIAN CAPITAL LETTER II */
 /*3822*/  0x010cd2,  1, 0x010c92, /* OLD HUNGARIAN CAPITAL LETTER EJ */
 /*3825*/  0x010cd3,  1, 0x010c93, /* OLD HUNGARIAN CAPITAL LETTER EK */
 /*3828*/  0x010cd4,  1, 0x010c94, /* OLD HUNGARIAN CAPITAL LETTER AK */
 /*3831*/  0x010cd5,  1, 0x010c95, /* OLD HUNGARIAN CAPITAL LETTER UNK */
 /*3834*/  0x010cd6,  1, 0x010c96, /* OLD HUNGARIAN CAPITAL LETTER EL */
 /*3837*/  0x010cd7,  1, 0x010c97, /* OLD HUNGARIAN CAPITAL LETTER ELY */
 /*3840*/  0x010cd8,  1, 0x010c98, /* OLD HUNGARIAN CAPITAL LETTER EM */
 /*3843*/  0x010cd9,  1, 0x010c99, /* OLD HUNGARIAN CAPITAL LETTER EN */
 /*3846*/  0x010cda,  1, 0x010c9a, /* OLD HUNGARIAN CAPITAL LETTER ENY */
 /*3849*/  0x010cdb,  1, 0x010c9b, /* OLD HUNGARIAN CAPITAL LETTER O */
 /*3852*/  0x010cdc,  1, 0x010c9c, /* OLD HUNGARIAN CAPITAL LETTER OO */
 /*3855*/  0x010cdd,  1, 0x010c9d, /* OLD HUNGARIAN CAPITAL LETTER NIKO.. */
 /*3858*/  0x010cde,  1, 0x010c9e, /* OLD HUNGARIAN CAPITAL LETTER RUDI.. */
 /*3861*/  0x010cdf,  1, 0x010c9f, /* OLD HUNGARIAN CAPITAL LETTER OEE */
 /*3864*/  0x010ce0,  1, 0x010ca0, /* OLD HUNGARIAN CAPITAL LETTER EP */
 /*3867*/  0x010ce1,  1, 0x010ca1, /* OLD HUNGARIAN CAPITAL LETTER EMP */
 /*3870*/  0x010ce2,  1, 0x010ca2, /* OLD HUNGARIAN CAPITAL LETTER ER */
 /*3873*/  0x010ce3,  1, 0x010ca3, /* OLD HUNGARIAN CAPITAL LETTER SHOR.. */
 /*3876*/  0x010ce4,  1, 0x010ca4, /* OLD HUNGARIAN CAPITAL LETTER ES */
 /*3879*/  0x010ce5,  1, 0x010ca5, /* OLD HUNGARIAN CAPITAL LETTER ESZ */
 /*3882*/  0x010ce6,  1, 0x010ca6, /* OLD HUNGARIAN CAPITAL LETTER ET */
 /*3885*/  0x010ce7,  1, 0x010ca7, /* OLD HUNGARIAN CAPITAL LETTER ENT */
 /*3888*/  0x010ce8,  1, 0x010ca8, /* OLD HUNGARIAN CAPITAL LETTER ETY */
 /*3891*/  0x010ce9,  1, 0x010ca9, /* OLD HUNGARIAN CAPITAL LETTER ECH */
 /*3894*/  0x010cea,  1, 0x010caa, /* OLD HUNGARIAN CAPITAL LETTER U */
 /*3897*/  0x010ceb,  1, 0x010cab, /* OLD HUNGARIAN CAPITAL LETTER UU */
 /*3900*/  0x010cec,  1, 0x010cac, /* OLD HUNGARIAN CAPITAL LETTER NIKO.. */
 /*3903*/  0x010ced,  1, 0x010cad, /* OLD HUNGARIAN CAPITAL LETTER RUDI.. */
 /*3906*/  0x010cee,  1, 0x010cae, /* OLD HUNGARIAN CAPITAL LETTER EV */
 /*3909*/  0x010cef,  1, 0x010caf, /* OLD HUNGARIAN CAPITAL LETTER EZ */
 /*3912*/  0x010cf0,  1, 0x010cb0, /* OLD HUNGARIAN CAPITAL LETTER EZS */
 /*3915*/  0x010cf1,  1, 0x010cb1, /* OLD HUNGARIAN CAPITAL LETTER ENT-.. */
 /*3918*/  0x010cf2,  1, 0x010cb2, /* OLD HUNGARIAN CAPITAL LETTER US */
 /*3921*/  0x0118c0,  1, 0x0118a0, /* WARANG CITI CAPITAL LETTER NGAA */
 /*3924*/  0x0118c1,  1, 0x0118a1, /* WARANG CITI CAPITAL LETTER A */
 /*3927*/  0x0118c2,  1, 0x0118a2, /* WARANG CITI CAPITAL LETTER WI */
 /*3930*/  0x0118c3,  1, 0x0118a3, /* WARANG CITI CAPITAL LETTER YU */
 /*3933*/  0x0118c4,  1, 0x0118a4, /* WARANG CITI CAPITAL LETTER YA */
 /*3936*/  0x0118c5,  1, 0x0118a5, /* WARANG CITI CAPITAL LETTER YO */
 /*3939*/  0x0118c6,  1, 0x0118a6, /* WARANG CITI CAPITAL LETTER II */
 /*3942*/  0x0118c7,  1, 0x0118a7, /* WARANG CITI CAPITAL LETTER UU */
 /*3945*/  0x0118c8,  1, 0x0118a8, /* WARANG CITI CAPITAL LETTER E */
 /*3948*/  0x0118c9,  1, 0x0118a9, /* WARANG CITI CAPITAL LETTER O */
 /*3951*/  0x0118ca,  1, 0x0118aa, /* WARANG CITI CAPITAL LETTER ANG */
 /*3954*/  0x0118cb,  1, 0x0118ab, /* WARANG CITI CAPITAL LETTER GA */
 /*3957*/  0x0118cc,  1, 0x0118ac, /* WARANG CITI CAPITAL LETTER KO */
 /*3960*/  0x0118cd,  1, 0x0118ad, /* WARANG CITI CAPITAL LETTER ENY */
 /*3963*/  0x0118ce,  1, 0x0118ae, /* WARANG CITI CAPITAL LETTER YUJ */
 /*3966*/  0x0118cf,  1, 0x0118af, /* WARANG CITI CAPITAL LETTER UC */
 /*3969*/  0x0118d0,  1, 0x0118b0, /* WARANG CITI CAPITAL LETTER ENN */
 /*3972*/  0x0118d1,  1, 0x0118b1, /* WARANG CITI CAPITAL LETTER ODD */
 /*3975*/  0x0118d2,  1, 0x0118b2, /* WARANG CITI CAPITAL LETTER TTE */
 /*3978*/  0x0118d3,  1, 0x0118b3, /* WARANG CITI CAPITAL LETTER NUNG */
 /*3981*/  0x0118d4,  1, 0x0118b4, /* WARANG CITI CAPITAL LETTER DA */
 /*3984*/  0x0118d5,  1, 0x0118b5, /* WARANG CITI CAPITAL LETTER AT */
 /*3987*/  0x0118d6,  1, 0x0118b6, /* WARANG CITI CAPITAL LETTER AM */
 /*3990*/  0x0118d7,  1, 0x0118b7, /* WARANG CITI CAPITAL LETTER BU */
 /*3993*/  0x0118d8,  1, 0x0118b8, /* WARANG CITI CAPITAL LETTER PU */
 /*3996*/  0x0118d9,  1, 0x0118b9, /* WARANG CITI CAPITAL LETTER HIYO */
 /*3999*/  0x0118da,  1, 0x0118ba, /* WARANG CITI CAPITAL LETTER HOLO */
 /*4002*/  0x0118db,  1, 0x0118bb, /* WARANG CITI CAPITAL LETTER HORR */
 /*4005*/  0x0118dc,  1, 0x0118bc, /* WARANG CITI CAPITAL LETTER HAR */
 /*4008*/  0x0118dd,  1, 0x0118bd, /* WARANG CITI CAPITAL LETTER SSUU */
 /*4011*/  0x0118de,  1, 0x0118be, /* WARANG CITI CAPITAL LETTER SII */
 /*4014*/  0x0118df,  1, 0x0118bf, /* WARANG CITI CAPITAL LETTER VIYO */
 /*4017*/  0x016e60,  1, 0x016e40, /* MEDEFAIDRIN CAPITAL LETTER M */
 /*4020*/  0x016e61,  1, 0x016e41, /* MEDEFAIDRIN CAPITAL LETTER S */
 /*4023*/  0x016e62,  1, 0x016e42, /* MEDEFAIDRIN CAPITAL LETTER V */
 /*4026*/  0x016e63,  1, 0x016e43, /* MEDEFAIDRIN CAPITAL LETTER W */
 /*4029*/  0x016e64,  1, 0x016e44, /* MEDEFAIDRIN CAPITAL LETTER ATIU */
 /*4032*/  0x016e65,  1, 0x016e45, /* MEDEFAIDRIN CAPITAL LETTER Z */
 /*4035*/  0x016e66,  1, 0x016e46, /* MEDEFAIDRIN CAPITAL LETTER KP */
 /*4038*/  0x016e67,  1, 0x016e47, /* MEDEFAIDRIN CAPITAL LETTER P */
 /*4041*/  0x016e68,  1, 0x016e48, /* MEDEFAIDRIN CAPITAL LETTER T */
 /*4044*/  0x016e69,  1, 0x016e49, /* MEDEFAIDRIN CAPITAL LETTER G */
 /*4047*/  0x016e6a,  1, 0x016e4a, /* MEDEFAIDRIN CAPITAL LETTER F */
 /*4050*/  0x016e6b,  1, 0x016e4b, /* MEDEFAIDRIN CAPITAL LETTER I */
 /*4053*/  0x016e6c,  1, 0x016e4c, /* MEDEFAIDRIN CAPITAL LETTER K */
 /*4056*/  0x016e6d,  1, 0x016e4d, /* MEDEFAIDRIN CAPITAL LETTER A */
 /*4059*/  0x016e6e,  1, 0x016e4e, /* MEDEFAIDRIN CAPITAL LETTER J */
 /*4062*/  0x016e6f,  1, 0x016e4f, /* MEDEFAIDRIN CAPITAL LETTER E */
 /*4065*/  0x016e70,  1, 0x016e50, /* MEDEFAIDRIN CAPITAL LETTER B */
 /*4068*/  0x016e71,  1, 0x016e51, /* MEDEFAIDRIN CAPITAL LETTER C */
 /*4071*/  0x016e72,  1, 0x016e52, /* MEDEFAIDRIN CAPITAL LETTER U */
 /*4074*/  0x016e73,  1, 0x016e53, /* MEDEFAIDRIN CAPITAL LETTER YU */
 /*4077*/  0x016e74,  1, 0x016e54, /* MEDEFAIDRIN CAPITAL LETTER L */
 /*4080*/  0x016e75,  1, 0x016e55, /* MEDEFAIDRIN CAPITAL LETTER Q */
 /*4083*/  0x016e76,  1, 0x016e56, /* MEDEFAIDRIN CAPITAL LETTER HP */
 /*4086*/  0x016e77,  1, 0x016e57, /* MEDEFAIDRIN CAPITAL LETTER NY */
 /*4089*/  0x016e78,  1, 0x016e58, /* MEDEFAIDRIN CAPITAL LETTER X */
 /*4092*/  0x016e79,  1, 0x016e59, /* MEDEFAIDRIN CAPITAL LETTER D */
 /*4095*/  0x016e7a,  1, 0x016e5a, /* MEDEFAIDRIN CAPITAL LETTER OE */
 /*4098*/  0x016e7b,  1, 0x016e5b, /* MEDEFAIDRIN CAPITAL LETTER N */
 /*4101*/  0x016e7c,  1, 0x016e5c, /* MEDEFAIDRIN CAPITAL LETTER R */
 /*4104*/  0x016e7d,  1, 0x016e5d, /* MEDEFAIDRIN CAPITAL LETTER O */
 /*4107*/  0x016e7e,  1, 0x016e5e, /* MEDEFAIDRIN CAPITAL LETTER AI */
 /*4110*/  0x016e7f,  1, 0x016e5f, /* MEDEFAIDRIN CAPITAL LETTER Y */
 /*4113*/  0x01e922,  1, 0x01e900, /* ADLAM CAPITAL LETTER ALIF */
 /*4116*/  0x01e923,  1, 0x01e901, /* ADLAM CAPITAL LETTER DAALI */
 /*4119*/  0x01e924,  1, 0x01e902, /* ADLAM CAPITAL LETTER LAAM */
 /*4122*/  0x01e925,  1, 0x01e903, /* ADLAM CAPITAL LETTER MIIM */
 /*4125*/  0x01e926,  1, 0x01e904, /* ADLAM CAPITAL LETTER BA */
 /*4128*/  0x01e927,  1, 0x01e905, /* ADLAM CAPITAL LETTER SINNYIIYHE */
 /*4131*/  0x01e928,  1, 0x01e906, /* ADLAM CAPITAL LETTER PE */
 /*4134*/  0x01e929,  1, 0x01e907, /* ADLAM CAPITAL LETTER BHE */
 /*4137*/  0x01e92a,  1, 0x01e908, /* ADLAM CAPITAL LETTER RA */
 /*4140*/  0x01e92b,  1, 0x01e909, /* ADLAM CAPITAL LETTER E */
 /*4143*/  0x01e92c,  1, 0x01e90a, /* ADLAM CAPITAL LETTER FA */
 /*4146*/  0x01e92d,  1, 0x01e90b, /* ADLAM CAPITAL LETTER I */
 /*4149*/  0x01e92e,  1, 0x01e90c, /* ADLAM CAPITAL LETTER O */
 /*4152*/  0x01e92f,  1, 0x01e90d, /* ADLAM CAPITAL LETTER DHA */
 /*4155*/  0x01e930,  1, 0x01e90e, /* ADLAM CAPITAL LETTER YHE */
 /*4158*/  0x01e931,  1, 0x01e90f, /* ADLAM CAPITAL LETTER WAW */
 /*4161*/  0x01e932,  1, 0x01e910, /* ADLAM CAPITAL LETTER NUN */
 /*4164*/  0x01e933,  1, 0x01e911, /* ADLAM CAPITAL LETTER KAF */
 /*4167*/  0x01e934,  1, 0x01e912, /* ADLAM CAPITAL LETTER YA */
 /*4170*/  0x01e935,  1, 0x01e913, /* ADLAM CAPITAL LETTER U */
 /*4173*/  0x01e936,  1, 0x01e914, /* ADLAM CAPITAL LETTER JIIM */
 /*4176*/  0x01e937,  1, 0x01e915, /* ADLAM CAPITAL LETTER CHI */
 /*4179*/  0x01e938,  1, 0x01e916, /* ADLAM CAPITAL LETTER HA */
 /*4182*/  0x01e939,  1, 0x01e917, /* ADLAM CAPITAL LETTER QAAF */
 /*4185*/  0x01e93a,  1, 0x01e918, /* ADLAM CAPITAL LETTER GA */
 /*4188*/  0x01e93b,  1, 0x01e919, /* ADLAM CAPITAL LETTER NYA */
 /*4191*/  0x01e93c,  1, 0x01e91a, /* ADLAM CAPITAL LETTER TU */
 /*4194*/  0x01e93d,  1, 0x01e91b, /* ADLAM CAPITAL LETTER NHA */
 /*4197*/  0x01e93e,  1, 0x01e91c, /* ADLAM CAPITAL LETTER VA */
 /*4200*/  0x01e93f,  1, 0x01e91d, /* ADLAM CAPITAL LETTER KHA */
 /*4203*/  0x01e940,  1, 0x01e91e, /* ADLAM CAPITAL LETTER GBE */
 /*4206*/  0x01e941,  1, 0x01e91f, /* ADLAM CAPITAL LETTER ZAL */
 /*4209*/  0x01e942,  1, 0x01e920, /* ADLAM CAPITAL LETTER KPO */
 /*4212*/  0x01e943,  1, 0x01e921, /* ADLAM CAPITAL LETTER SHA */
#define FOLDS1_NORMAL_END_INDEX   4215
 /* ----- LOCALE ----- */
 /*4215*/    0x0069,  1,   0x0049, /* LATIN CAPITAL LETTER I */
#define FOLDS1_END_INDEX   4218
};

OnigCodePoint OnigUnicodeFolds2[] = {
 /* LATIN SMALL LETTER A WITH RIGHT HALF RING */
 /*   0*/    0x0061,   0x02be,  1,   0x1e9a,
 /* LATIN SMALL LIGATURE FF */
 /*   4*/    0x0066,   0x0066,  1,   0xfb00,
 /* LATIN SMALL LIGATURE FI */
 /*   8*/    0x0066,   0x0069,  1,   0xfb01,
 /* LATIN SMALL LIGATURE FL */
 /*  12*/    0x0066,   0x006c,  1,   0xfb02,
 /* LATIN SMALL LETTER H WITH LINE BELOW */
 /*  16*/    0x0068,   0x0331,  1,   0x1e96,
 /* LATIN SMALL LETTER J WITH CARON */
 /*  20*/    0x006a,   0x030c,  1,   0x01f0,
 /* LATIN SMALL LETTER SHARP S */
 /*  24*/    0x0073,   0x0073,  2,   0x00df,   0x1e9e,
 /* LATIN SMALL LIGATURE LONG S T */
 /*  29*/    0x0073,   0x0074,  2,   0xfb05,   0xfb06,
 /* LATIN SMALL LETTER T WITH DIAERESIS */
 /*  34*/    0x0074,   0x0308,  1,   0x1e97,
 /* LATIN SMALL LETTER W WITH RING ABOVE */
 /*  38*/    0x0077,   0x030a,  1,   0x1e98,
 /* LATIN SMALL LETTER Y WITH RING ABOVE */
 /*  42*/    0x0079,   0x030a,  1,   0x1e99,
 /* LATIN SMALL LETTER N PRECEDED BY APOSTROPHE */
 /*  46*/    0x02bc,   0x006e,  1,   0x0149,
 /* GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI */
 /*  50*/    0x03ac,   0x03b9,  1,   0x1fb4,
 /* GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI */
 /*  54*/    0x03ae,   0x03b9,  1,   0x1fc4,
 /* GREEK SMALL LETTER ALPHA WITH PERISPOMENI */
 /*  58*/    0x03b1,   0x0342,  1,   0x1fb6,
 /* GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI */
 /*  62*/    0x03b1,   0x03b9,  2,   0x1fb3,   0x1fbc,
 /* GREEK SMALL LETTER ETA WITH PERISPOMENI */
 /*  67*/    0x03b7,   0x0342,  1,   0x1fc6,
 /* GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI */
 /*  71*/    0x03b7,   0x03b9,  2,   0x1fc3,   0x1fcc,
 /* GREEK SMALL LETTER IOTA WITH PERISPOMENI */
 /*  76*/    0x03b9,   0x0342,  1,   0x1fd6,
 /* GREEK SMALL LETTER RHO WITH PSILI */
 /*  80*/    0x03c1,   0x0313,  1,   0x1fe4,
 /* GREEK SMALL LETTER UPSILON WITH PSILI */
 /*  84*/    0x03c5,   0x0313,  1,   0x1f50,
 /* GREEK SMALL LETTER UPSILON WITH PERISPOMENI */
 /*  88*/    0x03c5,   0x0342,  1,   0x1fe6,
 /* GREEK SMALL LETTER OMEGA WITH PERISPOMENI */
 /*  92*/    0x03c9,   0x0342,  1,   0x1ff6,
 /* GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI */
 /*  96*/    0x03c9,   0x03b9,  2,   0x1ff3,   0x1ffc,
 /* GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI */
 /* 101*/    0x03ce,   0x03b9,  1,   0x1ff4,
 /* ARMENIAN SMALL LIGATURE ECH YIWN */
 /* 105*/    0x0565,   0x0582,  1,   0x0587,
 /* ARMENIAN SMALL LIGATURE MEN ECH */
 /* 109*/    0x0574,   0x0565,  1,   0xfb14,
 /* ARMENIAN SMALL LIGATURE MEN INI */
 /* 113*/    0x0574,   0x056b,  1,   0xfb15,
 /* ARMENIAN SMALL LIGATURE MEN XEH */
 /* 117*/    0x0574,   0x056d,  1,   0xfb17,
 /* ARMENIAN SMALL LIGATURE MEN NOW */
 /* 121*/    0x0574,   0x0576,  1,   0xfb13,
 /* ARMENIAN SMALL LIGATURE VEW NOW */
 /* 125*/    0x057e,   0x0576,  1,   0xfb16,
 /* GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI */
 /* 129*/    0x1f00,   0x03b9,  2,   0x1f80,   0x1f88,
 /* GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI */
 /* 134*/    0x1f01,   0x03b9,  2,   0x1f81,   0x1f89,
 /* GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI */
 /* 139*/    0x1f02,   0x03b9,  2,   0x1f82,   0x1f8a,
 /* GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI */
 /* 144*/    0x1f03,   0x03b9,  2,   0x1f83,   0x1f8b,
 /* GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI */
 /* 149*/    0x1f04,   0x03b9,  2,   0x1f84,   0x1f8c,
 /* GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI */
 /* 154*/    0x1f05,   0x03b9,  2,   0x1f85,   0x1f8d,
 /* GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI */
 /* 159*/    0x1f06,   0x03b9,  2,   0x1f86,   0x1f8e,
 /* GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI */
 /* 164*/    0x1f07,   0x03b9,  2,   0x1f87,   0x1f8f,
 /* GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI */
 /* 169*/    0x1f20,   0x03b9,  2,   0x1f90,   0x1f98,
 /* GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI */
 /* 174*/    0x1f21,   0x03b9,  2,   0x1f91,   0x1f99,
 /* GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI */
 /* 179*/    0x1f22,   0x03b9,  2,   0x1f92,   0x1f9a,
 /* GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI */
 /* 184*/    0x1f23,   0x03b9,  2,   0x1f93,   0x1f9b,
 /* GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI */
 /* 189*/    0x1f24,   0x03b9,  2,   0x1f94,   0x1f9c,
 /* GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI */
 /* 194*/    0x1f25,   0x03b9,  2,   0x1f95,   0x1f9d,
 /* GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI */
 /* 199*/    0x1f26,   0x03b9,  2,   0x1f96,   0x1f9e,
 /* GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI */
 /* 204*/    0x1f27,   0x03b9,  2,   0x1f97,   0x1f9f,
 /* GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI */
 /* 209*/    0x1f60,   0x03b9,  2,   0x1fa0,   0x1fa8,
 /* GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI */
 /* 214*/    0x1f61,   0x03b9,  2,   0x1fa1,   0x1fa9,
 /* GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI */
 /* 219*/    0x1f62,   0x03b9,  2,   0x1fa2,   0x1faa,
 /* GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI */
 /* 224*/    0x1f63,   0x03b9,  2,   0x1fa3,   0x1fab,
 /* GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI */
 /* 229*/    0x1f64,   0x03b9,  2,   0x1fa4,   0x1fac,
 /* GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI */
 /* 234*/    0x1f65,   0x03b9,  2,   0x1fa5,   0x1fad,
 /* GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI */
 /* 239*/    0x1f66,   0x03b9,  2,   0x1fa6,   0x1fae,
 /* GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI */
 /* 244*/    0x1f67,   0x03b9,  2,   0x1fa7,   0x1faf,
 /* GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI */
 /* 249*/    0x1f70,   0x03b9,  1,   0x1fb2,
 /* GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI */
 /* 253*/    0x1f74,   0x03b9,  1,   0x1fc2,
 /* GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI */
 /* 257*/    0x1f7c,   0x03b9,  1,   0x1ff2,
#define FOLDS2_NORMAL_END_INDEX   261
 /* ----- LOCALE ----- */
 /* LATIN CAPITAL LETTER I WITH DOT ABOVE */
 /* 261*/    0x0069,   0x0307,  1,   0x0130,
#define FOLDS2_END_INDEX   265
};

OnigCodePoint OnigUnicodeFolds3[] = {
 /* LATIN SMALL LIGATURE FFI */
 /*   0*/    0x0066,   0x0066,   0x0069,  1,   0xfb03,
 /* LATIN SMALL LIGATURE FFL */
 /*   5*/    0x0066,   0x0066,   0x006c,  1,   0xfb04,
 /* GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI */
 /*  10*/    0x03b1,   0x0342,   0x03b9,  1,   0x1fb7,
 /* GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI */
 /*  15*/    0x03b7,   0x0342,   0x03b9,  1,   0x1fc7,
 /* GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA */
 /*  20*/    0x03b9,   0x0308,   0x0300,  1,   0x1fd2,
 /* GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS */
 /*  25*/    0x03b9,   0x0308,   0x0301,  2,   0x0390,   0x1fd3,
 /* GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI */
 /*  31*/    0x03b9,   0x0308,   0x0342,  1,   0x1fd7,
 /* GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA */
 /*  36*/    0x03c5,   0x0308,   0x0300,  1,   0x1fe2,
 /* GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS */
 /*  41*/    0x03c5,   0x0308,   0x0301,  2,   0x03b0,   0x1fe3,
 /* GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI */
 /*  47*/    0x03c5,   0x0308,   0x0342,  1,   0x1fe7,
 /* GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA */
 /*  52*/    0x03c5,   0x0313,   0x0300,  1,   0x1f52,
 /* GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA */
 /*  57*/    0x03c5,   0x0313,   0x0301,  1,   0x1f54,
 /* GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI */
 /*  62*/    0x03c5,   0x0313,   0x0342,  1,   0x1f56,
 /* GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI */
 /*  67*/    0x03c9,   0x0342,   0x03b9,  1,   0x1ff7,
#define FOLDS3_NORMAL_END_INDEX   72
 /* ----- LOCALE ----- */
#define FOLDS3_END_INDEX   72
};
